# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from . import ai
from .. import _compat
from .ip import IP as IP
from .fax import Fax as Fax
from .fqdn import Fqdn as Fqdn
from .room import Room as Room
from .record import Record as Record
from .shared import (
    APIError as APIError,
    Metadata as Metadata,
    ShortCode as ShortCode,
    HostedNumber as HostedNumber,
    SimCardStatus as SimCardStatus,
    SimpleSimCard as SimpleSimCard,
    RoomParticipant as RoomParticipant,
    PortingOrderStatus as PortingOrderStatus,
    MessagingFeatureSet as MessagingFeatureSet,
    NumberHealthMetrics as NumberHealthMetrics,
    MinimaxVoiceSettings as MinimaxVoiceSettings,
    InboundMessagePayload as InboundMessagePayload,
    ConnectionJitterBuffer as ConnectionJitterBuffer,
    DocReqsRequirementType as DocReqsRequirementType,
    MessagingPaginationMeta as MessagingPaginationMeta,
    ConnectionsPaginationMeta as ConnectionsPaginationMeta,
    MessagingHostedNumberOrder as MessagingHostedNumberOrder,
    PortingOrdersExceptionType as PortingOrdersExceptionType,
    AvailablePhoneNumbersMetadata as AvailablePhoneNumbersMetadata,
    PhoneNumberWithMessagingSettings as PhoneNumberWithMessagingSettings,
    ConnectionNoiseSuppressionDetails as ConnectionNoiseSuppressionDetails,
    SubNumberOrderRegulatoryRequirementWithValue as SubNumberOrderRegulatoryRequirementWithValue,
)
from .address import Address as Address
from .sim_card import SimCard as SimCard
from .dtmf_type import DtmfType as DtmfType
from .rcs_agent import RcsAgent as RcsAgent
from .conference import Conference as Conference
from .fax_failed import FaxFailed as FaxFailed
from .fax_queued import FaxQueued as FaxQueued
from .inbound_ip import InboundIP as InboundIP
from .sip_header import SipHeader as SipHeader
from .call_hangup import CallHangup as CallHangup
from .oauth_grant import OAuthGrant as OAuthGrant
from .outbound_ip import OutboundIP as OutboundIP
from .call_bridged import CallBridged as CallBridged
from .inbound_fqdn import InboundFqdn as InboundFqdn
from .month_detail import MonthDetail as MonthDetail
from .oauth_client import OAuthClient as OAuthClient
from .phone_number import PhoneNumber as PhoneNumber
from .room_session import RoomSession as RoomSession
from .service_plan import ServicePlan as ServicePlan
from .stream_codec import StreamCodec as StreamCodec
from .traffic_type import TrafficType as TrafficType
from .user_address import UserAddress as UserAddress
from .verification import Verification as Verification
from .video_region import VideoRegion as VideoRegion
from .billing_group import BillingGroup as BillingGroup
from .call_answered import CallAnswered as CallAnswered
from .call_enqueued import CallEnqueued as CallEnqueued
from .consumed_data import ConsumedData as ConsumedData
from .fax_delivered import FaxDelivered as FaxDelivered
from .ip_connection import IPConnection as IPConnection
from .outbound_fqdn import OutboundFqdn as OutboundFqdn
from .porting_order import PortingOrder as PortingOrder
from .transcription import Transcription as Transcription
from .call_initiated import CallInitiated as CallInitiated
from .ip_list_params import IPListParams as IPListParams
from .media_resource import MediaResource as MediaResource
from .rcs_suggestion import RcsSuggestion as RcsSuggestion
from .settings_param import SettingsParam as SettingsParam
from .sim_card_group import SimCardGroup as SimCardGroup
from .sim_card_order import SimCardOrder as SimCardOrder
from .verify_profile import VerifyProfile as VerifyProfile
from .whatsapp_media import WhatsappMedia as WhatsappMedia
from .access_ip_range import AccessIPRange as AccessIPRange
from .call_left_queue import CallLeftQueue as CallLeftQueue
from .encrypted_media import EncryptedMedia as EncryptedMedia
from .fax_application import FaxApplication as FaxApplication
from .fax_list_params import FaxListParams as FaxListParams
from .fqdn_connection import FqdnConnection as FqdnConnection
from .inbound_message import InboundMessage as InboundMessage
from .managed_account import ManagedAccount as ManagedAccount
from .messaging_error import MessagingError as MessagingError
from .pagination_meta import PaginationMeta as PaginationMeta
from .portout_details import PortoutDetails as PortoutDetails
from .push_credential import PushCredential as PushCredential
from .verified_number import VerifiedNumber as VerifiedNumber
from .call_dial_params import CallDialParams as CallDialParams
from .call_speak_ended import CallSpeakEnded as CallSpeakEnded
from .conference_ended import ConferenceEnded as ConferenceEnded
from .fqdn_list_params import FqdnListParams as FqdnListParams
from .inbound_ip_param import InboundIPParam as InboundIPParam
from .interface_status import InterfaceStatus as InterfaceStatus
from .ip_create_params import IPCreateParams as IPCreateParams
from .ip_update_params import IPUpdateParams as IPUpdateParams
from .message_template import MessageTemplate as MessageTemplate
from .outbound_message import OutboundMessage as OutboundMessage
from .rcs_card_content import RcsCardContent as RcsCardContent
from .rcs_content_info import RcsContentInfo as RcsContentInfo
from .room_composition import RoomComposition as RoomComposition
from .room_list_params import RoomListParams as RoomListParams
from .sip_header_param import SipHeaderParam as SipHeaderParam
from .sub_number_order import SubNumberOrder as SubNumberOrder
from .available_service import AvailableService as AvailableService
from .call_fork_started import CallForkStarted as CallForkStarted
from .call_fork_stopped import CallForkStopped as CallForkStopped
from .call_gather_ended import CallGatherEnded as CallGatherEnded
from .call_refer_failed import CallReferFailed as CallReferFailed
from .custom_sip_header import CustomSipHeader as CustomSipHeader
from .fax_create_params import FaxCreateParams as FaxCreateParams
from .media_list_params import MediaListParams as MediaListParams
from .messaging_profile import MessagingProfile as MessagingProfile
from .network_interface import NetworkInterface as NetworkInterface
from .outbound_ip_param import OutboundIPParam as OutboundIPParam
from .rcs_agent_message import RcsAgentMessage as RcsAgentMessage
from .requirement_group import RequirementGroup as RequirementGroup
from .texml_application import TexmlApplication as TexmlApplication
from .call_dial_response import CallDialResponse as CallDialResponse
from .call_dtmf_received import CallDtmfReceived as CallDtmfReceived
from .call_refer_started import CallReferStarted as CallReferStarted
from .call_siprec_failed import CallSiprecFailed as CallSiprecFailed
from .call_speak_started import CallSpeakStarted as CallSpeakStarted
from .conference_created import ConferenceCreated as ConferenceCreated
from .credential_inbound import CredentialInbound as CredentialInbound
from .fqdn_create_params import FqdnCreateParams as FqdnCreateParams
from .fqdn_update_params import FqdnUpdateParams as FqdnUpdateParams
from .inbound_fqdn_param import InboundFqdnParam as InboundFqdnParam
from .integration_secret import IntegrationSecret as IntegrationSecret
from .ip_create_response import IPCreateResponse as IPCreateResponse
from .ip_delete_response import IPDeleteResponse as IPDeleteResponse
from .ip_update_response import IPUpdateResponse as IPUpdateResponse
from .number_block_order import NumberBlockOrder as NumberBlockOrder
from .number_reservation import NumberReservation as NumberReservation
from .oauth_token_params import OAuthTokenParams as OAuthTokenParams
from .porting_order_misc import PortingOrderMisc as PortingOrderMisc
from .porting_order_type import PortingOrderType as PortingOrderType
from .rcs_agent_response import RcsAgentResponse as RcsAgentResponse
from .room_create_params import RoomCreateParams as RoomCreateParams
from .room_update_params import RoomUpdateParams as RoomUpdateParams
from .transport_protocol import TransportProtocol as TransportProtocol
from .video_region_param import VideoRegionParam as VideoRegionParam
from .wireless_blocklist import WirelessBlocklist as WirelessBlocklist
from .address_list_params import AddressListParams as AddressListParams
from .ai_summarize_params import AISummarizeParams as AISummarizeParams
from .anchorsite_override import AnchorsiteOverride as AnchorsiteOverride
from .call_playback_ended import CallPlaybackEnded as CallPlaybackEnded
from .call_siprec_started import CallSiprecStarted as CallSiprecStarted
from .call_siprec_stopped import CallSiprecStopped as CallSiprecStopped
from .comment_list_params import CommentListParams as CommentListParams
from .credential_outbound import CredentialOutbound as CredentialOutbound
from .external_connection import ExternalConnection as ExternalConnection
from .fax_create_response import FaxCreateResponse as FaxCreateResponse
from .fax_media_processed import FaxMediaProcessed as FaxMediaProcessed
from .fax_sending_started import FaxSendingStarted as FaxSendingStarted
from .invoice_list_params import InvoiceListParams as InvoiceListParams
from .media_list_response import MediaListResponse as MediaListResponse
from .media_update_params import MediaUpdateParams as MediaUpdateParams
from .media_upload_params import MediaUploadParams as MediaUploadParams
from .message_send_params import MessageSendParams as MessageSendParams
from .mobile_phone_number import MobilePhoneNumber as MobilePhoneNumber
from .network_list_params import NetworkListParams as NetworkListParams
from .oauth_grants_params import OAuthGrantsParams as OAuthGrantsParams
from .outbound_fqdn_param import OutboundFqdnParam as OutboundFqdnParam
from .portout_list_params import PortoutListParams as PortoutListParams
from .replaced_link_click import ReplacedLinkClick as ReplacedLinkClick
from .verify_profile_data import VerifyProfileData as VerifyProfileData
from .webhook_api_version import WebhookAPIVersion as WebhookAPIVersion
from .call_ai_gather_ended import CallAIGatherEnded as CallAIGatherEnded
from .call_recording_error import CallRecordingError as CallRecordingError
from .call_recording_saved import CallRecordingSaved as CallRecordingSaved
from .call_refer_completed import CallReferCompleted as CallReferCompleted
from .doc_service_document import DocServiceDocument as DocServiceDocument
from .document_list_params import DocumentListParams as DocumentListParams
from .fqdn_create_response import FqdnCreateResponse as FqdnCreateResponse
from .fqdn_delete_response import FqdnDeleteResponse as FqdnDeleteResponse
from .fqdn_update_response import FqdnUpdateResponse as FqdnUpdateResponse
from .global_ip_assignment import GlobalIPAssignment as GlobalIPAssignment
from .ip_retrieve_response import IPRetrieveResponse as IPRetrieveResponse
from .notification_channel import NotificationChannel as NotificationChannel
from .notification_profile import NotificationProfile as NotificationProfile
from .notification_setting import NotificationSetting as NotificationSetting
from .number_pool_settings import NumberPoolSettings as NumberPoolSettings
from .oauth_token_response import OAuthTokenResponse as OAuthTokenResponse
from .rcs_suggestion_param import RcsSuggestionParam as RcsSuggestionParam
from .region_list_response import RegionListResponse as RegionListResponse
from .room_create_response import RoomCreateResponse as RoomCreateResponse
from .room_retrieve_params import RoomRetrieveParams as RoomRetrieveParams
from .room_update_response import RoomUpdateResponse as RoomUpdateResponse
from .sim_card_list_params import SimCardListParams as SimCardListParams
from .telephony_credential import TelephonyCredential as TelephonyCredential
from .texml_secrets_params import TexmlSecretsParams as TexmlSecretsParams
from .unwrap_webhook_event import UnwrapWebhookEvent as UnwrapWebhookEvent
from .usage_payment_method import UsagePaymentMethod as UsagePaymentMethod
from .user_tag_list_params import UserTagListParams as UserTagListParams
from .whatsapp_media_param import WhatsappMediaParam as WhatsappMediaParam
from .wireguard_peer_patch import WireguardPeerPatch as WireguardPeerPatch
from .address_create_params import AddressCreateParams as AddressCreateParams
from .ai_summarize_response import AISummarizeResponse as AISummarizeResponse
from .call_playback_started import CallPlaybackStarted as CallPlaybackStarted
from .call_streaming_failed import CallStreamingFailed as CallStreamingFailed
from .comment_create_params import CommentCreateParams as CommentCreateParams
from .comment_list_response import CommentListResponse as CommentListResponse
from .credential_connection import CredentialConnection as CredentialConnection
from .fax_retrieve_response import FaxRetrieveResponse as FaxRetrieveResponse
from .global_ip_list_params import GlobalIPListParams as GlobalIPListParams
from .invoice_list_response import InvoiceListResponse as InvoiceListResponse
from .media_update_response import MediaUpdateResponse as MediaUpdateResponse
from .media_upload_response import MediaUploadResponse as MediaUploadResponse
from .message_send_response import MessageSendResponse as MessageSendResponse
from .network_create_params import NetworkCreateParams as NetworkCreateParams
from .network_list_response import NetworkListResponse as NetworkListResponse
from .network_update_params import NetworkUpdateParams as NetworkUpdateParams
from .oauth_grants_response import OAuthGrantsResponse as OAuthGrantsResponse
from .oauth_register_params import OAuthRegisterParams as OAuthRegisterParams
from .pagination_meta_oauth import PaginationMetaOAuth as PaginationMetaOAuth
from .phone_number_detailed import PhoneNumberDetailed as PhoneNumberDetailed
from .recording_list_params import RecordingListParams as RecordingListParams
from .reserved_phone_number import ReservedPhoneNumber as ReservedPhoneNumber
from .s3_configuration_data import S3ConfigurationData as S3ConfigurationData
from .call_event_list_params import CallEventListParams as CallEventListParams
from .call_streaming_started import CallStreamingStarted as CallStreamingStarted
from .call_streaming_stopped import CallStreamingStopped as CallStreamingStopped
from .campaign_status_update import CampaignStatusUpdate as CampaignStatusUpdate
from .cloudflare_sync_status import CloudflareSyncStatus as CloudflareSyncStatus
from .conference_list_params import ConferenceListParams as ConferenceListParams
from .conference_speak_ended import ConferenceSpeakEnded as ConferenceSpeakEnded
from .connection_list_params import ConnectionListParams as ConnectionListParams
from .document_update_params import DocumentUpdateParams as DocumentUpdateParams
from .document_upload_params import DocumentUploadParams as DocumentUploadParams
from .fqdn_retrieve_response import FqdnRetrieveResponse as FqdnRetrieveResponse
from .gcs_configuration_data import GcsConfigurationData as GcsConfigurationData
from .ota_update_list_params import OtaUpdateListParams as OtaUpdateListParams
from .outbound_voice_profile import OutboundVoiceProfile as OutboundVoiceProfile
from .porting_order_end_user import PortingOrderEndUser as PortingOrderEndUser
from .rcs_card_content_param import RcsCardContentParam as RcsCardContentParam
from .rcs_content_info_param import RcsContentInfoParam as RcsContentInfoParam
from .room_retrieve_response import RoomRetrieveResponse as RoomRetrieveResponse
from .short_code_list_params import ShortCodeListParams as ShortCodeListParams
from .sim_card_delete_params import SimCardDeleteParams as SimCardDeleteParams
from .sim_card_update_params import SimCardUpdateParams as SimCardUpdateParams
from .texml_secrets_response import TexmlSecretsResponse as TexmlSecretsResponse
from .url_shortener_settings import URLShortenerSettings as URLShortenerSettings
from .user_tag_list_response import UserTagListResponse as UserTagListResponse
from .address_create_response import AddressCreateResponse as AddressCreateResponse
from .address_delete_response import AddressDeleteResponse as AddressDeleteResponse
from .audit_event_list_params import AuditEventListParams as AuditEventListParams
from .authentication_provider import AuthenticationProvider as AuthenticationProvider
from .call_conversation_ended import CallConversationEnded as CallConversationEnded
from .comment_create_response import CommentCreateResponse as CommentCreateResponse
from .custom_sip_header_param import CustomSipHeaderParam as CustomSipHeaderParam
from .customer_service_record import CustomerServiceRecord as CustomerServiceRecord
from .dialogflow_config_param import DialogflowConfigParam as DialogflowConfigParam
from .global_ip_create_params import GlobalIPCreateParams as GlobalIPCreateParams
from .global_ip_list_response import GlobalIPListResponse as GlobalIPListResponse
from .invoice_retrieve_params import InvoiceRetrieveParams as InvoiceRetrieveParams
from .managed_account_balance import ManagedAccountBalance as ManagedAccountBalance
from .media_retrieve_response import MediaRetrieveResponse as MediaRetrieveResponse
from .message_schedule_params import MessageScheduleParams as MessageScheduleParams
from .mobile_voice_connection import MobileVoiceConnection as MobileVoiceConnection
from .network_create_response import NetworkCreateResponse as NetworkCreateResponse
from .network_delete_response import NetworkDeleteResponse as NetworkDeleteResponse
from .network_update_response import NetworkUpdateResponse as NetworkUpdateResponse
from .oauth_grant_list_params import OAuthGrantListParams as OAuthGrantListParams
from .oauth_introspect_params import OAuthIntrospectParams as OAuthIntrospectParams
from .oauth_register_response import OAuthRegisterResponse as OAuthRegisterResponse
from .oauth_retrieve_response import OAuthRetrieveResponse as OAuthRetrieveResponse
from .outbound_call_recording import OutboundCallRecording as OutboundCallRecording
from .porting_order_documents import PortingOrderDocuments as PortingOrderDocuments
from .porting_order_messaging import PortingOrderMessaging as PortingOrderMessaging
from .queue_retrieve_response import QueueRetrieveResponse as QueueRetrieveResponse
from .rcs_agent_message_param import RcsAgentMessageParam as RcsAgentMessageParam
from .recording_response_data import RecordingResponseData as RecordingResponseData
from .recording_transcription import RecordingTranscription as RecordingTranscription
from .report_list_mdrs_params import ReportListMdrsParams as ReportListMdrsParams
from .report_list_wdrs_params import ReportListWdrsParams as ReportListWdrsParams
from .requirement_list_params import RequirementListParams as RequirementListParams
from .azure_configuration_data import AzureConfigurationData as AzureConfigurationData
from .call_control_application import CallControlApplication as CallControlApplication
from .call_event_list_response import CallEventListResponse as CallEventListResponse
from .channel_zone_list_params import ChannelZoneListParams as ChannelZoneListParams
from .conference_create_params import ConferenceCreateParams as ConferenceCreateParams
from .conference_floor_changed import ConferenceFloorChanged as ConferenceFloorChanged
from .conference_speak_started import ConferenceSpeakStarted as ConferenceSpeakStarted
from .connection_list_response import ConnectionListResponse as ConnectionListResponse
from .connection_rtcp_settings import ConnectionRtcpSettings as ConnectionRtcpSettings
from .credential_inbound_param import CredentialInboundParam as CredentialInboundParam
from .document_delete_response import DocumentDeleteResponse as DocumentDeleteResponse
from .document_update_response import DocumentUpdateResponse as DocumentUpdateResponse
from .document_upload_response import DocumentUploadResponse as DocumentUploadResponse
from .network_interface_region import NetworkInterfaceRegion as NetworkInterfaceRegion
from .number_order_list_params import NumberOrderListParams as NumberOrderListParams
from .oauth_client_list_params import OAuthClientListParams as OAuthClientListParams
from .ota_update_list_response import OtaUpdateListResponse as OtaUpdateListResponse
from .outbound_message_payload import OutboundMessagePayload as OutboundMessagePayload
from .phone_number_list_params import PhoneNumberListParams as PhoneNumberListParams
from .porting_order_misc_param import PortingOrderMiscParam as PortingOrderMiscParam
from .private_wireless_gateway import PrivateWirelessGateway as PrivateWirelessGateway
from .push_credential_response import PushCredentialResponse as PushCredentialResponse
from .short_code_update_params import ShortCodeUpdateParams as ShortCodeUpdateParams
from .sim_card_delete_response import SimCardDeleteResponse as SimCardDeleteResponse
from .sim_card_retrieve_params import SimCardRetrieveParams as SimCardRetrieveParams
from .sim_card_update_response import SimCardUpdateResponse as SimCardUpdateResponse
from .usage_report_list_params import UsageReportListParams as UsageReportListParams
from .user_address_list_params import UserAddressListParams as UserAddressListParams
from .address_retrieve_response import AddressRetrieveResponse as AddressRetrieveResponse
from .audit_event_list_response import AuditEventListResponse as AuditEventListResponse
from .balance_retrieve_response import BalanceRetrieveResponse as BalanceRetrieveResponse
from .billing_group_list_params import BillingGroupListParams as BillingGroupListParams
from .call_hangup_webhook_event import CallHangupWebhookEvent as CallHangupWebhookEvent
from .comment_retrieve_response import CommentRetrieveResponse as CommentRetrieveResponse
from .conference_playback_ended import ConferencePlaybackEnded as ConferencePlaybackEnded
from .credential_outbound_param import CredentialOutboundParam as CredentialOutboundParam
from .detail_record_list_params import DetailRecordListParams as DetailRecordListParams
from .document_link_list_params import DocumentLinkListParams as DocumentLinkListParams
from .dynamic_emergency_address import DynamicEmergencyAddress as DynamicEmergencyAddress
from .global_ip_create_response import GlobalIPCreateResponse as GlobalIPCreateResponse
from .global_ip_delete_response import GlobalIPDeleteResponse as GlobalIPDeleteResponse
from .invoice_retrieve_response import InvoiceRetrieveResponse as InvoiceRetrieveResponse
from .ip_connection_list_params import IPConnectionListParams as IPConnectionListParams
from .message_retrieve_response import MessageRetrieveResponse as MessageRetrieveResponse
from .message_schedule_response import MessageScheduleResponse as MessageScheduleResponse
from .network_retrieve_response import NetworkRetrieveResponse as NetworkRetrieveResponse
from .number_order_phone_number import NumberOrderPhoneNumber as NumberOrderPhoneNumber
from .oauth_introspect_response import OAuthIntrospectResponse as OAuthIntrospectResponse
from .porting_order_list_params import PortingOrderListParams as PortingOrderListParams
from .porting_order_requirement import PortingOrderRequirement as PortingOrderRequirement
from .portout_retrieve_response import PortoutRetrieveResponse as PortoutRetrieveResponse
from .recording_delete_response import RecordingDeleteResponse as RecordingDeleteResponse
from .report_list_mdrs_response import ReportListMdrsResponse as ReportListMdrsResponse
from .report_list_wdrs_response import ReportListWdrsResponse as ReportListWdrsResponse
from .requirement_list_response import RequirementListResponse as RequirementListResponse
from .sound_modifications_param import SoundModificationsParam as SoundModificationsParam
from .stream_bidirectional_mode import StreamBidirectionalMode as StreamBidirectionalMode
from .access_ip_address_response import AccessIPAddressResponse as AccessIPAddressResponse
from .call_bridged_webhook_event import CallBridgedWebhookEvent as CallBridgedWebhookEvent
from .channel_zone_list_response import ChannelZoneListResponse as ChannelZoneListResponse
from .channel_zone_update_params import ChannelZoneUpdateParams as ChannelZoneUpdateParams
from .conference_create_response import ConferenceCreateResponse as ConferenceCreateResponse
from .conference_recording_saved import ConferenceRecordingSaved as ConferenceRecordingSaved
from .conference_retrieve_params import ConferenceRetrieveParams as ConferenceRetrieveParams
from .document_retrieve_response import DocumentRetrieveResponse as DocumentRetrieveResponse
from .dynamic_emergency_endpoint import DynamicEmergencyEndpoint as DynamicEmergencyEndpoint
from .global_ip_assignment_param import GlobalIPAssignmentParam as GlobalIPAssignmentParam
from .list_retrieve_all_response import ListRetrieveAllResponse as ListRetrieveAllResponse
from .number_order_create_params import NumberOrderCreateParams as NumberOrderCreateParams
from .number_order_list_response import NumberOrderListResponse as NumberOrderListResponse
from .number_order_status_update import NumberOrderStatusUpdate as NumberOrderStatusUpdate
from .number_order_update_params import NumberOrderUpdateParams as NumberOrderUpdateParams
from .number_pool_settings_param import NumberPoolSettingsParam as NumberPoolSettingsParam
from .oauth_client_create_params import OAuthClientCreateParams as OAuthClientCreateParams
from .oauth_client_update_params import OAuthClientUpdateParams as OAuthClientUpdateParams
from .phone_number_update_params import PhoneNumberUpdateParams as PhoneNumberUpdateParams
from .room_recording_list_params import RoomRecordingListParams as RoomRecordingListParams
from .short_code_update_response import ShortCodeUpdateResponse as ShortCodeUpdateResponse
from .sim_card_group_list_params import SimCardGroupListParams as SimCardGroupListParams
from .sim_card_order_list_params import SimCardOrderListParams as SimCardOrderListParams
from .sim_card_retrieve_response import SimCardRetrieveResponse as SimCardRetrieveResponse
from .stream_bidirectional_codec import StreamBidirectionalCodec as StreamBidirectionalCodec
from .usage_report_list_response import UsageReportListResponse as UsageReportListResponse
from .user_address_create_params import UserAddressCreateParams as UserAddressCreateParams
from .verify_profile_list_params import VerifyProfileListParams as VerifyProfileListParams
from .wireguard_peer_list_params import WireguardPeerListParams as WireguardPeerListParams
from .access_ip_range_list_params import AccessIPRangeListParams as AccessIPRangeListParams
from .ai_retrieve_models_response import AIRetrieveModelsResponse as AIRetrieveModelsResponse
from .billing_group_create_params import BillingGroupCreateParams as BillingGroupCreateParams
from .billing_group_update_params import BillingGroupUpdateParams as BillingGroupUpdateParams
from .call_answered_webhook_event import CallAnsweredWebhookEvent as CallAnsweredWebhookEvent
from .call_enqueued_webhook_event import CallEnqueuedWebhookEvent as CallEnqueuedWebhookEvent
from .call_machine_greeting_ended import CallMachineGreetingEnded as CallMachineGreetingEnded
from .conference_participant_left import ConferenceParticipantLeft as ConferenceParticipantLeft
from .conference_playback_started import ConferencePlaybackStarted as ConferencePlaybackStarted
from .detail_record_list_response import DetailRecordListResponse as DetailRecordListResponse
from .document_link_list_response import DocumentLinkListResponse as DocumentLinkListResponse
from .document_upload_json_params import DocumentUploadJsonParams as DocumentUploadJsonParams
from .fax_application_list_params import FaxApplicationListParams as FaxApplicationListParams
from .fqdn_connection_list_params import FqdnConnectionListParams as FqdnConnectionListParams
from .global_ip_retrieve_response import GlobalIPRetrieveResponse as GlobalIPRetrieveResponse
from .ip_connection_create_params import IPConnectionCreateParams as IPConnectionCreateParams
from .ip_connection_update_params import IPConnectionUpdateParams as IPConnectionUpdateParams
from .ledger_billing_group_report import LedgerBillingGroupReport as LedgerBillingGroupReport
from .managed_account_list_params import ManagedAccountListParams as ManagedAccountListParams
from .oauth_grant_delete_response import OAuthGrantDeleteResponse as OAuthGrantDeleteResponse
from .porting_order_create_params import PortingOrderCreateParams as PortingOrderCreateParams
from .porting_order_update_params import PortingOrderUpdateParams as PortingOrderUpdateParams
from .porting_order_user_feedback import PortingOrderUserFeedback as PortingOrderUserFeedback
from .recording_retrieve_response import RecordingRetrieveResponse as RecordingRetrieveResponse
from .reserved_phone_number_param import ReservedPhoneNumberParam as ReservedPhoneNumberParam
from .s3_configuration_data_param import S3ConfigurationDataParam as S3ConfigurationDataParam
from .transcription_webhook_event import TranscriptionWebhookEvent as TranscriptionWebhookEvent
from .unsafe_unwrap_webhook_event import UnsafeUnwrapWebhookEvent as UnsafeUnwrapWebhookEvent
from .verified_number_list_params import VerifiedNumberListParams as VerifiedNumberListParams
from .advanced_order_create_params import AdvancedOrderCreateParams as AdvancedOrderCreateParams
from .advanced_order_list_response import AdvancedOrderListResponse as AdvancedOrderListResponse
from .call_initiated_webhook_event import CallInitiatedWebhookEvent as CallInitiatedWebhookEvent
from .call_machine_detection_ended import CallMachineDetectionEnded as CallMachineDetectionEnded
from .channel_zone_update_response import ChannelZoneUpdateResponse as ChannelZoneUpdateResponse
from .conference_retrieve_response import ConferenceRetrieveResponse as ConferenceRetrieveResponse
from .connection_retrieve_response import ConnectionRetrieveResponse as ConnectionRetrieveResponse
from .create_verification_response import CreateVerificationResponse as CreateVerificationResponse
from .custom_storage_configuration import CustomStorageConfiguration as CustomStorageConfiguration
from .gcs_configuration_data_param import GcsConfigurationDataParam as GcsConfigurationDataParam
from .message_send_whatsapp_params import MessageSendWhatsappParams as MessageSendWhatsappParams
from .messaging_optout_list_params import MessagingOptoutListParams as MessagingOptoutListParams
from .network_coverage_list_params import NetworkCoverageListParams as NetworkCoverageListParams
from .number_order_create_response import NumberOrderCreateResponse as NumberOrderCreateResponse
from .number_order_update_response import NumberOrderUpdateResponse as NumberOrderUpdateResponse
from .oauth_client_create_response import OAuthClientCreateResponse as OAuthClientCreateResponse
from .oauth_client_update_response import OAuthClientUpdateResponse as OAuthClientUpdateResponse
from .oauth_retrieve_jwks_response import OAuthRetrieveJwksResponse as OAuthRetrieveJwksResponse
from .ota_update_retrieve_response import OtaUpdateRetrieveResponse as OtaUpdateRetrieveResponse
from .phone_number_delete_response import PhoneNumberDeleteResponse as PhoneNumberDeleteResponse
from .phone_number_update_response import PhoneNumberUpdateResponse as PhoneNumberUpdateResponse
from .portability_check_run_params import PortabilityCheckRunParams as PortabilityCheckRunParams
from .porting_order_end_user_admin import PortingOrderEndUserAdmin as PortingOrderEndUserAdmin
from .porting_order_end_user_param import PortingOrderEndUserParam as PortingOrderEndUserParam
from .portout_update_status_params import PortoutUpdateStatusParams as PortoutUpdateStatusParams
from .requirement_type_list_params import RequirementTypeListParams as RequirementTypeListParams
from .room_composition_list_params import RoomCompositionListParams as RoomCompositionListParams
from .room_participant_list_params import RoomParticipantListParams as RoomParticipantListParams
from .room_recording_list_response import RoomRecordingListResponse as RoomRecordingListResponse
from .short_code_retrieve_response import ShortCodeRetrieveResponse as ShortCodeRetrieveResponse
from .sim_card_group_create_params import SimCardGroupCreateParams as SimCardGroupCreateParams
from .sim_card_group_list_response import SimCardGroupListResponse as SimCardGroupListResponse
from .sim_card_group_update_params import SimCardGroupUpdateParams as SimCardGroupUpdateParams
from .sim_card_order_create_params import SimCardOrderCreateParams as SimCardOrderCreateParams
from .sub_number_order_list_params import SubNumberOrderListParams as SubNumberOrderListParams
from .url_shortener_settings_param import URLShortenerSettingsParam as URLShortenerSettingsParam
from .user_address_create_response import UserAddressCreateResponse as UserAddressCreateResponse
from .verified_number_data_wrapper import VerifiedNumberDataWrapper as VerifiedNumberDataWrapper
from .verify_profile_create_params import VerifyProfileCreateParams as VerifyProfileCreateParams
from .verify_profile_update_params import VerifyProfileUpdateParams as VerifyProfileUpdateParams
from .webhook_delivery_list_params import WebhookDeliveryListParams as WebhookDeliveryListParams
from .wireguard_peer_create_params import WireguardPeerCreateParams as WireguardPeerCreateParams
from .wireguard_peer_list_response import WireguardPeerListResponse as WireguardPeerListResponse
from .wireguard_peer_update_params import WireguardPeerUpdateParams as WireguardPeerUpdateParams
from .access_ip_address_list_params import AccessIPAddressListParams as AccessIPAddressListParams
from .access_ip_range_create_params import AccessIPRangeCreateParams as AccessIPRangeCreateParams
from .billing_group_create_response import BillingGroupCreateResponse as BillingGroupCreateResponse
from .billing_group_delete_response import BillingGroupDeleteResponse as BillingGroupDeleteResponse
from .billing_group_update_response import BillingGroupUpdateResponse as BillingGroupUpdateResponse
from .call_left_queue_webhook_event import CallLeftQueueWebhookEvent as CallLeftQueueWebhookEvent
from .call_retrieve_status_response import CallRetrieveStatusResponse as CallRetrieveStatusResponse
from .comment_mark_as_read_response import CommentMarkAsReadResponse as CommentMarkAsReadResponse
from .conference_participant_joined import ConferenceParticipantJoined as ConferenceParticipantJoined
from .delivery_update_webhook_event import DeliveryUpdateWebhookEvent as DeliveryUpdateWebhookEvent
from .document_upload_json_response import DocumentUploadJsonResponse as DocumentUploadJsonResponse
from .fax_application_create_params import FaxApplicationCreateParams as FaxApplicationCreateParams
from .fax_application_update_params import FaxApplicationUpdateParams as FaxApplicationUpdateParams
from .fqdn_connection_create_params import FqdnConnectionCreateParams as FqdnConnectionCreateParams
from .fqdn_connection_update_params import FqdnConnectionUpdateParams as FqdnConnectionUpdateParams
from .inbound_channel_list_response import InboundChannelListResponse as InboundChannelListResponse
from .inbound_channel_update_params import InboundChannelUpdateParams as InboundChannelUpdateParams
from .inbound_message_webhook_event import InboundMessageWebhookEvent as InboundMessageWebhookEvent
from .ip_connection_create_response import IPConnectionCreateResponse as IPConnectionCreateResponse
from .ip_connection_delete_response import IPConnectionDeleteResponse as IPConnectionDeleteResponse
from .ip_connection_update_response import IPConnectionUpdateResponse as IPConnectionUpdateResponse
from .managed_account_create_params import ManagedAccountCreateParams as ManagedAccountCreateParams
from .managed_account_list_response import ManagedAccountListResponse as ManagedAccountListResponse
from .managed_account_update_params import ManagedAccountUpdateParams as ManagedAccountUpdateParams
from .message_send_group_mms_params import MessageSendGroupMmsParams as MessageSendGroupMmsParams
from .message_send_long_code_params import MessageSendLongCodeParams as MessageSendLongCodeParams
from .messaging_profile_list_params import MessagingProfileListParams as MessagingProfileListParams
from .number_lookup_retrieve_params import NumberLookupRetrieveParams as NumberLookupRetrieveParams
from .numbers_feature_create_params import NumbersFeatureCreateParams as NumbersFeatureCreateParams
from .oauth_grant_retrieve_response import OAuthGrantRetrieveResponse as OAuthGrantRetrieveResponse
from .outbound_call_recording_param import OutboundCallRecordingParam as OutboundCallRecordingParam
from .phone_number_slim_list_params import PhoneNumberSlimListParams as PhoneNumberSlimListParams
from .porting_order_create_response import PortingOrderCreateResponse as PortingOrderCreateResponse
from .porting_order_documents_param import PortingOrderDocumentsParam as PortingOrderDocumentsParam
from .porting_order_retrieve_params import PortingOrderRetrieveParams as PortingOrderRetrieveParams
from .porting_order_update_response import PortingOrderUpdateResponse as PortingOrderUpdateResponse
from .porting_orders_activation_job import PortingOrdersActivationJob as PortingOrdersActivationJob
from .requirement_group_list_params import RequirementGroupListParams as RequirementGroupListParams
from .requirement_retrieve_response import RequirementRetrieveResponse as RequirementRetrieveResponse
from .texml_application_list_params import TexmlApplicationListParams as TexmlApplicationListParams
from .verified_number_create_params import VerifiedNumberCreateParams as VerifiedNumberCreateParams
from .advanced_order_create_response import AdvancedOrderCreateResponse as AdvancedOrderCreateResponse
from .azure_configuration_data_param import AzureConfigurationDataParam as AzureConfigurationDataParam
from .call_ai_gather_partial_results import CallAIGatherPartialResults as CallAIGatherPartialResults
from .call_speak_ended_webhook_event import CallSpeakEndedWebhookEvent as CallSpeakEndedWebhookEvent
from .conference_ended_webhook_event import ConferenceEndedWebhookEvent as ConferenceEndedWebhookEvent
from .connection_rtcp_settings_param import ConnectionRtcpSettingsParam as ConnectionRtcpSettingsParam
from .integration_secret_list_params import IntegrationSecretListParams as IntegrationSecretListParams
from .inventory_coverage_list_params import InventoryCoverageListParams as InventoryCoverageListParams
from .list_retrieve_by_zone_response import ListRetrieveByZoneResponse as ListRetrieveByZoneResponse
from .message_send_short_code_params import MessageSendShortCodeParams as MessageSendShortCodeParams
from .message_send_whatsapp_response import MessageSendWhatsappResponse as MessageSendWhatsappResponse
from .messaging_optout_list_response import MessagingOptoutListResponse as MessagingOptoutListResponse
from .network_coverage_list_response import NetworkCoverageListResponse as NetworkCoverageListResponse
from .network_list_interfaces_params import NetworkListInterfacesParams as NetworkListInterfacesParams
from .notification_event_list_params import NotificationEventListParams as NotificationEventListParams
from .number_block_order_list_params import NumberBlockOrderListParams as NumberBlockOrderListParams
from .number_order_retrieve_response import NumberOrderRetrieveResponse as NumberOrderRetrieveResponse
from .number_reservation_list_params import NumberReservationListParams as NumberReservationListParams
from .oauth_client_retrieve_response import OAuthClientRetrieveResponse as OAuthClientRetrieveResponse
from .phone_number_retrieve_response import PhoneNumberRetrieveResponse as PhoneNumberRetrieveResponse
from .portability_check_run_response import PortabilityCheckRunResponse as PortabilityCheckRunResponse
from .portout_update_status_response import PortoutUpdateStatusResponse as PortoutUpdateStatusResponse
from .pwg_assigned_resources_summary import PwgAssignedResourcesSummary as PwgAssignedResourcesSummary
from .requirement_type_list_response import RequirementTypeListResponse as RequirementTypeListResponse
from .room_composition_create_params import RoomCompositionCreateParams as RoomCompositionCreateParams
from .sim_card_group_create_response import SimCardGroupCreateResponse as SimCardGroupCreateResponse
from .sim_card_group_delete_response import SimCardGroupDeleteResponse as SimCardGroupDeleteResponse
from .sim_card_group_retrieve_params import SimCardGroupRetrieveParams as SimCardGroupRetrieveParams
from .sim_card_group_update_response import SimCardGroupUpdateResponse as SimCardGroupUpdateResponse
from .sim_card_order_create_response import SimCardOrderCreateResponse as SimCardOrderCreateResponse
from .siprec_connector_create_params import SiprecConnectorCreateParams as SiprecConnectorCreateParams
from .siprec_connector_update_params import SiprecConnectorUpdateParams as SiprecConnectorUpdateParams
from .sub_number_order_list_response import SubNumberOrderListResponse as SubNumberOrderListResponse
from .sub_number_order_update_params import SubNumberOrderUpdateParams as SubNumberOrderUpdateParams
from .user_address_retrieve_response import UserAddressRetrieveResponse as UserAddressRetrieveResponse
from .verification_retrieve_response import VerificationRetrieveResponse as VerificationRetrieveResponse
from .webhook_delivery_list_response import WebhookDeliveryListResponse as WebhookDeliveryListResponse
from .wireguard_peer_create_response import WireguardPeerCreateResponse as WireguardPeerCreateResponse
from .wireguard_peer_delete_response import WireguardPeerDeleteResponse as WireguardPeerDeleteResponse
from .wireguard_peer_update_response import WireguardPeerUpdateResponse as WireguardPeerUpdateResponse
from .wireless_blocklist_list_params import WirelessBlocklistListParams as WirelessBlocklistListParams
from .access_ip_address_create_params import AccessIPAddressCreateParams as AccessIPAddressCreateParams
from .billing_group_retrieve_response import BillingGroupRetrieveResponse as BillingGroupRetrieveResponse
from .call_fork_started_webhook_event import CallForkStartedWebhookEvent as CallForkStartedWebhookEvent
from .call_fork_stopped_webhook_event import CallForkStoppedWebhookEvent as CallForkStoppedWebhookEvent
from .call_gather_ended_webhook_event import CallGatherEndedWebhookEvent as CallGatherEndedWebhookEvent
from .call_refer_failed_webhook_event import CallReferFailedWebhookEvent as CallReferFailedWebhookEvent
from .charges_summary_retrieve_params import ChargesSummaryRetrieveParams as ChargesSummaryRetrieveParams
from .external_connection_list_params import ExternalConnectionListParams as ExternalConnectionListParams
from .fax_application_create_response import FaxApplicationCreateResponse as FaxApplicationCreateResponse
from .fax_application_delete_response import FaxApplicationDeleteResponse as FaxApplicationDeleteResponse
from .fax_application_update_response import FaxApplicationUpdateResponse as FaxApplicationUpdateResponse
from .fqdn_connection_create_response import FqdnConnectionCreateResponse as FqdnConnectionCreateResponse
from .fqdn_connection_delete_response import FqdnConnectionDeleteResponse as FqdnConnectionDeleteResponse
from .fqdn_connection_update_response import FqdnConnectionUpdateResponse as FqdnConnectionUpdateResponse
from .global_ip_usage_retrieve_params import GlobalIPUsageRetrieveParams as GlobalIPUsageRetrieveParams
from .inbound_channel_update_response import InboundChannelUpdateResponse as InboundChannelUpdateResponse
from .ip_connection_retrieve_response import IPConnectionRetrieveResponse as IPConnectionRetrieveResponse
from .managed_account_create_response import ManagedAccountCreateResponse as ManagedAccountCreateResponse
from .managed_account_update_response import ManagedAccountUpdateResponse as ManagedAccountUpdateResponse
from .message_send_group_mms_response import MessageSendGroupMmsResponse as MessageSendGroupMmsResponse
from .message_send_long_code_response import MessageSendLongCodeResponse as MessageSendLongCodeResponse
from .message_send_number_pool_params import MessageSendNumberPoolParams as MessageSendNumberPoolParams
from .messaging_profile_create_params import MessagingProfileCreateParams as MessagingProfileCreateParams
from .messaging_profile_update_params import MessagingProfileUpdateParams as MessagingProfileUpdateParams
from .mobile_phone_number_list_params import MobilePhoneNumberListParams as MobilePhoneNumberListParams
from .number_lookup_retrieve_response import NumberLookupRetrieveResponse as NumberLookupRetrieveResponse
from .number_order_with_phone_numbers import NumberOrderWithPhoneNumbers as NumberOrderWithPhoneNumbers
from .numbers_feature_create_response import NumbersFeatureCreateResponse as NumbersFeatureCreateResponse
from .oauth_retrieve_authorize_params import OAuthRetrieveAuthorizeParams as OAuthRetrieveAuthorizeParams
from .phone_number_slim_list_response import PhoneNumberSlimListResponse as PhoneNumberSlimListResponse
from .porting_order_end_user_location import PortingOrderEndUserLocation as PortingOrderEndUserLocation
from .porting_order_retrieve_response import PortingOrderRetrieveResponse as PortingOrderRetrieveResponse
from .private_wireless_gateway_status import PrivateWirelessGatewayStatus as PrivateWirelessGatewayStatus
from .requirement_group_create_params import RequirementGroupCreateParams as RequirementGroupCreateParams
from .requirement_group_list_response import RequirementGroupListResponse as RequirementGroupListResponse
from .requirement_group_update_params import RequirementGroupUpdateParams as RequirementGroupUpdateParams
from .sim_card_get_public_ip_response import SimCardGetPublicIPResponse as SimCardGetPublicIPResponse
from .texml_application_create_params import TexmlApplicationCreateParams as TexmlApplicationCreateParams
from .texml_application_update_params import TexmlApplicationUpdateParams as TexmlApplicationUpdateParams
from .usage_report_get_options_params import UsageReportGetOptionsParams as UsageReportGetOptionsParams
from .verification_trigger_sms_params import VerificationTriggerSMSParams as VerificationTriggerSMSParams
from .verified_number_create_response import VerifiedNumberCreateResponse as VerifiedNumberCreateResponse
from .wireguard_interface_list_params import WireguardInterfaceListParams as WireguardInterfaceListParams
from .advanced_order_retrieve_response import AdvancedOrderRetrieveResponse as AdvancedOrderRetrieveResponse
from .bulk_sim_card_action_list_params import BulkSimCardActionListParams as BulkSimCardActionListParams
from .call_control_application_inbound import CallControlApplicationInbound as CallControlApplicationInbound
from .call_dtmf_received_webhook_event import CallDtmfReceivedWebhookEvent as CallDtmfReceivedWebhookEvent
from .call_refer_started_webhook_event import CallReferStartedWebhookEvent as CallReferStartedWebhookEvent
from .call_siprec_failed_webhook_event import CallSiprecFailedWebhookEvent as CallSiprecFailedWebhookEvent
from .call_speak_started_webhook_event import CallSpeakStartedWebhookEvent as CallSpeakStartedWebhookEvent
from .conference_created_webhook_event import ConferenceCreatedWebhookEvent as ConferenceCreatedWebhookEvent
from .global_ip_assignment_list_params import GlobalIPAssignmentListParams as GlobalIPAssignmentListParams
from .global_ip_protocol_list_response import GlobalIPProtocolListResponse as GlobalIPProtocolListResponse
from .inexplicit_number_order_response import InexplicitNumberOrderResponse as InexplicitNumberOrderResponse
from .integration_secret_create_params import IntegrationSecretCreateParams as IntegrationSecretCreateParams
from .inventory_coverage_list_response import InventoryCoverageListResponse as InventoryCoverageListResponse
from .message_send_short_code_response import MessageSendShortCodeResponse as MessageSendShortCodeResponse
from .messaging_url_domain_list_params import MessagingURLDomainListParams as MessagingURLDomainListParams
from .network_list_interfaces_response import NetworkListInterfacesResponse as NetworkListInterfacesResponse
from .notification_channel_list_params import NotificationChannelListParams as NotificationChannelListParams
from .notification_event_list_response import NotificationEventListResponse as NotificationEventListResponse
from .notification_profile_list_params import NotificationProfileListParams as NotificationProfileListParams
from .notification_setting_list_params import NotificationSettingListParams as NotificationSettingListParams
from .number_block_order_create_params import NumberBlockOrderCreateParams as NumberBlockOrderCreateParams
from .number_reservation_create_params import NumberReservationCreateParams as NumberReservationCreateParams
from .porting_phone_number_list_params import PortingPhoneNumberListParams as PortingPhoneNumberListParams
from .room_composition_create_response import RoomCompositionCreateResponse as RoomCompositionCreateResponse
from .room_recording_retrieve_response import RoomRecordingRetrieveResponse as RoomRecordingRetrieveResponse
from .sim_card_data_usage_notification import SimCardDataUsageNotification as SimCardDataUsageNotification
from .sim_card_group_retrieve_response import SimCardGroupRetrieveResponse as SimCardGroupRetrieveResponse
from .sim_card_order_retrieve_response import SimCardOrderRetrieveResponse as SimCardOrderRetrieveResponse
from .siprec_connector_create_response import SiprecConnectorCreateResponse as SiprecConnectorCreateResponse
from .siprec_connector_update_response import SiprecConnectorUpdateResponse as SiprecConnectorUpdateResponse
from .speech_to_text_transcribe_params import SpeechToTextTranscribeParams as SpeechToTextTranscribeParams
from .stream_bidirectional_target_legs import StreamBidirectionalTargetLegs as StreamBidirectionalTargetLegs
from .sub_number_order_cancel_response import SubNumberOrderCancelResponse as SubNumberOrderCancelResponse
from .sub_number_order_retrieve_params import SubNumberOrderRetrieveParams as SubNumberOrderRetrieveParams
from .sub_number_order_update_response import SubNumberOrderUpdateResponse as SubNumberOrderUpdateResponse
from .telephony_credential_list_params import TelephonyCredentialListParams as TelephonyCredentialListParams
from .verification_trigger_call_params import VerificationTriggerCallParams as VerificationTriggerCallParams
from .wireguard_peer_retrieve_response import WireguardPeerRetrieveResponse as WireguardPeerRetrieveResponse
from .wireless_blocklist_create_params import WirelessBlocklistCreateParams as WirelessBlocklistCreateParams
from .wireless_blocklist_update_params import WirelessBlocklistUpdateParams as WirelessBlocklistUpdateParams
from .wireless_retrieve_regions_params import WirelessRetrieveRegionsParams as WirelessRetrieveRegionsParams
from .call_control_application_outbound import CallControlApplicationOutbound as CallControlApplicationOutbound
from .call_playback_ended_webhook_event import CallPlaybackEndedWebhookEvent as CallPlaybackEndedWebhookEvent
from .call_siprec_started_webhook_event import CallSiprecStartedWebhookEvent as CallSiprecStartedWebhookEvent
from .call_siprec_stopped_webhook_event import CallSiprecStoppedWebhookEvent as CallSiprecStoppedWebhookEvent
from .charges_breakdown_retrieve_params import ChargesBreakdownRetrieveParams as ChargesBreakdownRetrieveParams
from .charges_summary_retrieve_response import ChargesSummaryRetrieveResponse as ChargesSummaryRetrieveResponse
from .credential_connection_list_params import CredentialConnectionListParams as CredentialConnectionListParams
from .external_connection_create_params import ExternalConnectionCreateParams as ExternalConnectionCreateParams
from .external_connection_update_params import ExternalConnectionUpdateParams as ExternalConnectionUpdateParams
from .fax_application_retrieve_response import FaxApplicationRetrieveResponse as FaxApplicationRetrieveResponse
from .fqdn_connection_retrieve_response import FqdnConnectionRetrieveResponse as FqdnConnectionRetrieveResponse
from .global_ip_latency_retrieve_params import GlobalIPLatencyRetrieveParams as GlobalIPLatencyRetrieveParams
from .global_ip_usage_retrieve_response import GlobalIPUsageRetrieveResponse as GlobalIPUsageRetrieveResponse
from .managed_account_retrieve_response import ManagedAccountRetrieveResponse as ManagedAccountRetrieveResponse
from .message_cancel_scheduled_response import MessageCancelScheduledResponse as MessageCancelScheduledResponse
from .message_send_number_pool_response import MessageSendNumberPoolResponse as MessageSendNumberPoolResponse
from .messaging_10dlc_get_enum_response import Messaging10dlcGetEnumResponse as Messaging10dlcGetEnumResponse
from .messaging_profile_create_response import MessagingProfileCreateResponse as MessagingProfileCreateResponse
from .messaging_profile_delete_response import MessagingProfileDeleteResponse as MessagingProfileDeleteResponse
from .messaging_profile_update_response import MessagingProfileUpdateResponse as MessagingProfileUpdateResponse
from .mobile_phone_number_update_params import MobilePhoneNumberUpdateParams as MobilePhoneNumberUpdateParams
from .porting_list_uk_carriers_response import PortingListUkCarriersResponse as PortingListUkCarriersResponse
from .porting_order_activation_settings import PortingOrderActivationSettings as PortingOrderActivationSettings
from .porting_order_user_feedback_param import PortingOrderUserFeedbackParam as PortingOrderUserFeedbackParam
from .replaced_link_click_webhook_event import ReplacedLinkClickWebhookEvent as ReplacedLinkClickWebhookEvent
from .room_recording_delete_bulk_params import RoomRecordingDeleteBulkParams as RoomRecordingDeleteBulkParams
from .texml_application_create_response import TexmlApplicationCreateResponse as TexmlApplicationCreateResponse
from .texml_application_delete_response import TexmlApplicationDeleteResponse as TexmlApplicationDeleteResponse
from .texml_application_update_response import TexmlApplicationUpdateResponse as TexmlApplicationUpdateResponse
from .text_to_speech_list_voices_params import TextToSpeechListVoicesParams as TextToSpeechListVoicesParams
from .usage_report_get_options_response import UsageReportGetOptionsResponse as UsageReportGetOptionsResponse
from .virtual_cross_connect_list_params import VirtualCrossConnectListParams as VirtualCrossConnectListParams
from .wireguard_interface_create_params import WireguardInterfaceCreateParams as WireguardInterfaceCreateParams
from .wireguard_interface_list_response import WireguardInterfaceListResponse as WireguardInterfaceListResponse
from .available_phone_number_list_params import AvailablePhoneNumberListParams as AvailablePhoneNumberListParams
from .bulk_sim_card_action_list_response import BulkSimCardActionListResponse as BulkSimCardActionListResponse
from .call_ai_gather_ended_webhook_event import CallAIGatherEndedWebhookEvent as CallAIGatherEndedWebhookEvent
from .call_recording_error_webhook_event import CallRecordingErrorWebhookEvent as CallRecordingErrorWebhookEvent
from .call_recording_saved_webhook_event import CallRecordingSavedWebhookEvent as CallRecordingSavedWebhookEvent
from .call_recording_transcription_saved import CallRecordingTranscriptionSaved as CallRecordingTranscriptionSaved
from .call_refer_completed_webhook_event import CallReferCompletedWebhookEvent as CallReferCompletedWebhookEvent
from .conference_participant_speak_ended import ConferenceParticipantSpeakEnded as ConferenceParticipantSpeakEnded
from .country_coverage_retrieve_response import CountryCoverageRetrieveResponse as CountryCoverageRetrieveResponse
from .global_ip_assignment_update_params import GlobalIPAssignmentUpdateParams as GlobalIPAssignmentUpdateParams
from .global_ip_health_check_list_params import GlobalIPHealthCheckListParams as GlobalIPHealthCheckListParams
from .integration_secret_create_response import IntegrationSecretCreateResponse as IntegrationSecretCreateResponse
from .messaging_url_domain_list_response import MessagingURLDomainListResponse as MessagingURLDomainListResponse
from .mobile_push_credential_list_params import MobilePushCredentialListParams as MobilePushCredentialListParams
from .notification_channel_create_params import NotificationChannelCreateParams as NotificationChannelCreateParams
from .notification_channel_update_params import NotificationChannelUpdateParams as NotificationChannelUpdateParams
from .notification_profile_create_params import NotificationProfileCreateParams as NotificationProfileCreateParams
from .notification_profile_update_params import NotificationProfileUpdateParams as NotificationProfileUpdateParams
from .notification_setting_create_params import NotificationSettingCreateParams as NotificationSettingCreateParams
from .number_block_order_create_response import NumberBlockOrderCreateResponse as NumberBlockOrderCreateResponse
from .number_reservation_create_response import NumberReservationCreateResponse as NumberReservationCreateResponse
from .outbound_voice_profile_list_params import OutboundVoiceProfileListParams as OutboundVoiceProfileListParams
from .porting_order_end_user_admin_param import PortingOrderEndUserAdminParam as PortingOrderEndUserAdminParam
from .porting_phone_number_list_response import PortingPhoneNumberListResponse as PortingPhoneNumberListResponse
from .requirement_type_retrieve_response import RequirementTypeRetrieveResponse as RequirementTypeRetrieveResponse
from .room_composition_retrieve_response import RoomCompositionRetrieveResponse as RoomCompositionRetrieveResponse
from .room_participant_retrieve_response import RoomParticipantRetrieveResponse as RoomParticipantRetrieveResponse
from .siprec_connector_retrieve_response import SiprecConnectorRetrieveResponse as SiprecConnectorRetrieveResponse
from .stream_bidirectional_sampling_rate import StreamBidirectionalSamplingRate as StreamBidirectionalSamplingRate
from .sub_number_order_retrieve_response import SubNumberOrderRetrieveResponse as SubNumberOrderRetrieveResponse
from .telephony_credential_create_params import TelephonyCredentialCreateParams as TelephonyCredentialCreateParams
from .telephony_credential_update_params import TelephonyCredentialUpdateParams as TelephonyCredentialUpdateParams
from .webhook_delivery_retrieve_response import WebhookDeliveryRetrieveResponse as WebhookDeliveryRetrieveResponse
from .wireless_blocklist_create_response import WirelessBlocklistCreateResponse as WirelessBlocklistCreateResponse
from .wireless_blocklist_delete_response import WirelessBlocklistDeleteResponse as WirelessBlocklistDeleteResponse
from .wireless_blocklist_update_response import WirelessBlocklistUpdateResponse as WirelessBlocklistUpdateResponse
from .wireless_retrieve_regions_response import WirelessRetrieveRegionsResponse as WirelessRetrieveRegionsResponse
from .authentication_provider_list_params import AuthenticationProviderListParams as AuthenticationProviderListParams
from .call_machine_premium_greeting_ended import CallMachinePremiumGreetingEnded as CallMachinePremiumGreetingEnded
from .call_playback_started_webhook_event import CallPlaybackStartedWebhookEvent as CallPlaybackStartedWebhookEvent
from .call_streaming_failed_webhook_event import CallStreamingFailedWebhookEvent as CallStreamingFailedWebhookEvent
from .charges_breakdown_retrieve_response import ChargesBreakdownRetrieveResponse as ChargesBreakdownRetrieveResponse
from .conference_list_participants_params import ConferenceListParticipantsParams as ConferenceListParticipantsParams
from .connection_list_active_calls_params import ConnectionListActiveCallsParams as ConnectionListActiveCallsParams
from .credential_connection_create_params import CredentialConnectionCreateParams as CredentialConnectionCreateParams
from .credential_connection_update_params import CredentialConnectionUpdateParams as CredentialConnectionUpdateParams
from .customer_service_record_list_params import CustomerServiceRecordListParams as CustomerServiceRecordListParams
from .dialogflow_connection_create_params import DialogflowConnectionCreateParams as DialogflowConnectionCreateParams
from .dialogflow_connection_update_params import DialogflowConnectionUpdateParams as DialogflowConnectionUpdateParams
from .external_connection_create_response import ExternalConnectionCreateResponse as ExternalConnectionCreateResponse
from .external_connection_delete_response import ExternalConnectionDeleteResponse as ExternalConnectionDeleteResponse
from .external_connection_update_response import ExternalConnectionUpdateResponse as ExternalConnectionUpdateResponse
from .global_ip_latency_retrieve_response import GlobalIPLatencyRetrieveResponse as GlobalIPLatencyRetrieveResponse
from .inexplicit_number_order_list_params import InexplicitNumberOrderListParams as InexplicitNumberOrderListParams
from .messaging_profile_retrieve_response import MessagingProfileRetrieveResponse as MessagingProfileRetrieveResponse
from .mobile_network_operator_list_params import MobileNetworkOperatorListParams as MobileNetworkOperatorListParams
from .mobile_phone_number_update_response import MobilePhoneNumberUpdateResponse as MobilePhoneNumberUpdateResponse
from .mobile_voice_connection_list_params import MobileVoiceConnectionListParams as MobileVoiceConnectionListParams
from .portout_list_rejection_codes_params import PortoutListRejectionCodesParams as PortoutListRejectionCodesParams
from .public_internet_gateway_list_params import PublicInternetGatewayListParams as PublicInternetGatewayListParams
from .room_recording_delete_bulk_response import RoomRecordingDeleteBulkResponse as RoomRecordingDeleteBulkResponse
from .texml_application_retrieve_response import TexmlApplicationRetrieveResponse as TexmlApplicationRetrieveResponse
from .text_to_speech_list_voices_response import TextToSpeechListVoicesResponse as TextToSpeechListVoicesResponse
from .update_regulatory_requirement_param import UpdateRegulatoryRequirementParam as UpdateRegulatoryRequirementParam
from .virtual_cross_connect_create_params import VirtualCrossConnectCreateParams as VirtualCrossConnectCreateParams
from .virtual_cross_connect_list_response import VirtualCrossConnectListResponse as VirtualCrossConnectListResponse
from .virtual_cross_connect_update_params import VirtualCrossConnectUpdateParams as VirtualCrossConnectUpdateParams
from .wireguard_interface_create_response import WireguardInterfaceCreateResponse as WireguardInterfaceCreateResponse
from .wireguard_interface_delete_response import WireguardInterfaceDeleteResponse as WireguardInterfaceDeleteResponse
from .available_phone_number_list_response import AvailablePhoneNumberListResponse as AvailablePhoneNumberListResponse
from .call_control_application_list_params import CallControlApplicationListParams as CallControlApplicationListParams
from .call_conversation_insights_generated import CallConversationInsightsGenerated as CallConversationInsightsGenerated
from .call_machine_premium_detection_ended import CallMachinePremiumDetectionEnded as CallMachinePremiumDetectionEnded
from .call_streaming_started_webhook_event import CallStreamingStartedWebhookEvent as CallStreamingStartedWebhookEvent
from .call_streaming_stopped_webhook_event import CallStreamingStoppedWebhookEvent as CallStreamingStoppedWebhookEvent
from .conference_participant_speak_started import ConferenceParticipantSpeakStarted as ConferenceParticipantSpeakStarted
from .conference_speak_ended_webhook_event import ConferenceSpeakEndedWebhookEvent as ConferenceSpeakEndedWebhookEvent
from .global_ip_allowed_port_list_response import GlobalIPAllowedPortListResponse as GlobalIPAllowedPortListResponse
from .global_ip_assignment_create_response import GlobalIPAssignmentCreateResponse as GlobalIPAssignmentCreateResponse
from .global_ip_assignment_delete_response import GlobalIPAssignmentDeleteResponse as GlobalIPAssignmentDeleteResponse
from .global_ip_assignment_update_response import GlobalIPAssignmentUpdateResponse as GlobalIPAssignmentUpdateResponse
from .global_ip_health_check_create_params import GlobalIPHealthCheckCreateParams as GlobalIPHealthCheckCreateParams
from .global_ip_health_check_list_response import GlobalIPHealthCheckListResponse as GlobalIPHealthCheckListResponse
from .mobile_push_credential_create_params import MobilePushCredentialCreateParams as MobilePushCredentialCreateParams
from .notification_channel_create_response import NotificationChannelCreateResponse as NotificationChannelCreateResponse
from .notification_channel_delete_response import NotificationChannelDeleteResponse as NotificationChannelDeleteResponse
from .notification_channel_update_response import NotificationChannelUpdateResponse as NotificationChannelUpdateResponse
from .notification_profile_create_response import NotificationProfileCreateResponse as NotificationProfileCreateResponse
from .notification_profile_delete_response import NotificationProfileDeleteResponse as NotificationProfileDeleteResponse
from .notification_profile_update_response import NotificationProfileUpdateResponse as NotificationProfileUpdateResponse
from .notification_setting_create_response import NotificationSettingCreateResponse as NotificationSettingCreateResponse
from .notification_setting_delete_response import NotificationSettingDeleteResponse as NotificationSettingDeleteResponse
from .number_block_order_retrieve_response import NumberBlockOrderRetrieveResponse as NumberBlockOrderRetrieveResponse
from .number_reservation_retrieve_response import NumberReservationRetrieveResponse as NumberReservationRetrieveResponse
from .outbound_voice_profile_create_params import OutboundVoiceProfileCreateParams as OutboundVoiceProfileCreateParams
from .outbound_voice_profile_update_params import OutboundVoiceProfileUpdateParams as OutboundVoiceProfileUpdateParams
from .private_wireless_gateway_list_params import PrivateWirelessGatewayListParams as PrivateWirelessGatewayListParams
from .sim_card_get_device_details_response import SimCardGetDeviceDetailsResponse as SimCardGetDeviceDetailsResponse
from .telephony_credential_create_response import TelephonyCredentialCreateResponse as TelephonyCredentialCreateResponse
from .telephony_credential_delete_response import TelephonyCredentialDeleteResponse as TelephonyCredentialDeleteResponse
from .telephony_credential_update_response import TelephonyCredentialUpdateResponse as TelephonyCredentialUpdateResponse
from .wireless_blocklist_retrieve_response import WirelessBlocklistRetrieveResponse as WirelessBlocklistRetrieveResponse
from .wireless_blocklist_value_list_params import WirelessBlocklistValueListParams as WirelessBlocklistValueListParams
from .authentication_provider_create_params import (
    AuthenticationProviderCreateParams as AuthenticationProviderCreateParams,
)
from .authentication_provider_update_params import (
    AuthenticationProviderUpdateParams as AuthenticationProviderUpdateParams,
)
from .call_conversation_ended_webhook_event import (
    CallConversationEndedWebhookEvent as CallConversationEndedWebhookEvent,
)
from .conference_list_participants_response import (
    ConferenceListParticipantsResponse as ConferenceListParticipantsResponse,
)
from .conference_participant_playback_ended import (
    ConferenceParticipantPlaybackEnded as ConferenceParticipantPlaybackEnded,
)
from .connection_list_active_calls_response import (
    ConnectionListActiveCallsResponse as ConnectionListActiveCallsResponse,
)
from .credential_connection_create_response import (
    CredentialConnectionCreateResponse as CredentialConnectionCreateResponse,
)
from .credential_connection_delete_response import (
    CredentialConnectionDeleteResponse as CredentialConnectionDeleteResponse,
)
from .credential_connection_update_response import (
    CredentialConnectionUpdateResponse as CredentialConnectionUpdateResponse,
)
from .customer_service_record_create_params import (
    CustomerServiceRecordCreateParams as CustomerServiceRecordCreateParams,
)
from .dialogflow_connection_create_response import (
    DialogflowConnectionCreateResponse as DialogflowConnectionCreateResponse,
)
from .dialogflow_connection_update_response import (
    DialogflowConnectionUpdateResponse as DialogflowConnectionUpdateResponse,
)
from .dynamic_emergency_address_list_params import (
    DynamicEmergencyAddressListParams as DynamicEmergencyAddressListParams,
)
from .external_connection_retrieve_response import (
    ExternalConnectionRetrieveResponse as ExternalConnectionRetrieveResponse,
)
from .inexplicit_number_order_create_params import (
    InexplicitNumberOrderCreateParams as InexplicitNumberOrderCreateParams,
)
from .mobile_network_operator_list_response import (
    MobileNetworkOperatorListResponse as MobileNetworkOperatorListResponse,
)
from .mobile_phone_number_retrieve_response import (
    MobilePhoneNumberRetrieveResponse as MobilePhoneNumberRetrieveResponse,
)
from .mobile_voice_connection_create_params import (
    MobileVoiceConnectionCreateParams as MobileVoiceConnectionCreateParams,
)
from .mobile_voice_connection_update_params import (
    MobileVoiceConnectionUpdateParams as MobileVoiceConnectionUpdateParams,
)
from .number_order_phone_number_list_params import NumberOrderPhoneNumberListParams as NumberOrderPhoneNumberListParams
from .porting_order_end_user_location_param import PortingOrderEndUserLocationParam as PortingOrderEndUserLocationParam
from .portout_list_rejection_codes_response import (
    PortoutListRejectionCodesResponse as PortoutListRejectionCodesResponse,
)
from .public_internet_gateway_create_params import (
    PublicInternetGatewayCreateParams as PublicInternetGatewayCreateParams,
)
from .public_internet_gateway_list_response import (
    PublicInternetGatewayListResponse as PublicInternetGatewayListResponse,
)
from .recording_transcription_list_response import (
    RecordingTranscriptionListResponse as RecordingTranscriptionListResponse,
)
from .sim_card_get_activation_code_response import SimCardGetActivationCodeResponse as SimCardGetActivationCodeResponse
from .sim_card_order_preview_preview_params import SimCardOrderPreviewPreviewParams as SimCardOrderPreviewPreviewParams
from .text_to_speech_generate_speech_params import TextToSpeechGenerateSpeechParams as TextToSpeechGenerateSpeechParams
from .verification_trigger_flashcall_params import (
    VerificationTriggerFlashcallParams as VerificationTriggerFlashcallParams,
)
from .verify_profile_create_template_params import (
    VerifyProfileCreateTemplateParams as VerifyProfileCreateTemplateParams,
)
from .verify_profile_update_template_params import (
    VerifyProfileUpdateTemplateParams as VerifyProfileUpdateTemplateParams,
)
from .virtual_cross_connect_create_response import (
    VirtualCrossConnectCreateResponse as VirtualCrossConnectCreateResponse,
)
from .virtual_cross_connect_delete_response import (
    VirtualCrossConnectDeleteResponse as VirtualCrossConnectDeleteResponse,
)
from .virtual_cross_connect_update_response import (
    VirtualCrossConnectUpdateResponse as VirtualCrossConnectUpdateResponse,
)
from .wireguard_interface_retrieve_response import (
    WireguardInterfaceRetrieveResponse as WireguardInterfaceRetrieveResponse,
)
from .bulk_sim_card_action_retrieve_response import (
    BulkSimCardActionRetrieveResponse as BulkSimCardActionRetrieveResponse,
)
from .call_ai_gather_message_history_updated import (
    CallAIGatherMessageHistoryUpdated as CallAIGatherMessageHistoryUpdated,
)
from .call_control_application_create_params import (
    CallControlApplicationCreateParams as CallControlApplicationCreateParams,
)
from .call_control_application_inbound_param import (
    CallControlApplicationInboundParam as CallControlApplicationInboundParam,
)
from .call_control_application_update_params import (
    CallControlApplicationUpdateParams as CallControlApplicationUpdateParams,
)
from .conference_speak_started_webhook_event import (
    ConferenceSpeakStartedWebhookEvent as ConferenceSpeakStartedWebhookEvent,
)
from .dynamic_emergency_endpoint_list_params import (
    DynamicEmergencyEndpointListParams as DynamicEmergencyEndpointListParams,
)
from .global_ip_assignment_retrieve_response import (
    GlobalIPAssignmentRetrieveResponse as GlobalIPAssignmentRetrieveResponse,
)
from .global_ip_health_check_create_response import (
    GlobalIPHealthCheckCreateResponse as GlobalIPHealthCheckCreateResponse,
)
from .global_ip_health_check_delete_response import (
    GlobalIPHealthCheckDeleteResponse as GlobalIPHealthCheckDeleteResponse,
)
from .notification_channel_retrieve_response import (
    NotificationChannelRetrieveResponse as NotificationChannelRetrieveResponse,
)
from .notification_profile_retrieve_response import (
    NotificationProfileRetrieveResponse as NotificationProfileRetrieveResponse,
)
from .notification_setting_retrieve_response import (
    NotificationSettingRetrieveResponse as NotificationSettingRetrieveResponse,
)
from .outbound_voice_profile_create_response import (
    OutboundVoiceProfileCreateResponse as OutboundVoiceProfileCreateResponse,
)
from .outbound_voice_profile_delete_response import (
    OutboundVoiceProfileDeleteResponse as OutboundVoiceProfileDeleteResponse,
)
from .outbound_voice_profile_update_response import (
    OutboundVoiceProfileUpdateResponse as OutboundVoiceProfileUpdateResponse,
)
from .private_wireless_gateway_create_params import (
    PrivateWirelessGatewayCreateParams as PrivateWirelessGatewayCreateParams,
)
from .regulatory_requirement_retrieve_params import (
    RegulatoryRequirementRetrieveParams as RegulatoryRequirementRetrieveParams,
)
from .sub_number_orders_report_create_params import (
    SubNumberOrdersReportCreateParams as SubNumberOrdersReportCreateParams,
)
from .telephony_credential_retrieve_response import (
    TelephonyCredentialRetrieveResponse as TelephonyCredentialRetrieveResponse,
)
from .wireless_blocklist_value_list_response import (
    WirelessBlocklistValueListResponse as WirelessBlocklistValueListResponse,
)
from .authentication_provider_create_response import (
    AuthenticationProviderCreateResponse as AuthenticationProviderCreateResponse,
)
from .authentication_provider_delete_response import (
    AuthenticationProviderDeleteResponse as AuthenticationProviderDeleteResponse,
)
from .authentication_provider_update_response import (
    AuthenticationProviderUpdateResponse as AuthenticationProviderUpdateResponse,
)
from .call_control_application_outbound_param import (
    CallControlApplicationOutboundParam as CallControlApplicationOutboundParam,
)
from .conference_participant_playback_started import (
    ConferenceParticipantPlaybackStarted as ConferenceParticipantPlaybackStarted,
)
from .conference_playback_ended_webhook_event import (
    ConferencePlaybackEndedWebhookEvent as ConferencePlaybackEndedWebhookEvent,
)
from .credential_connection_retrieve_response import (
    CredentialConnectionRetrieveResponse as CredentialConnectionRetrieveResponse,
)
from .custom_storage_credential_create_params import (
    CustomStorageCredentialCreateParams as CustomStorageCredentialCreateParams,
)
from .custom_storage_credential_update_params import (
    CustomStorageCredentialUpdateParams as CustomStorageCredentialUpdateParams,
)
from .customer_service_record_create_response import (
    CustomerServiceRecordCreateResponse as CustomerServiceRecordCreateResponse,
)
from .dialogflow_connection_retrieve_response import (
    DialogflowConnectionRetrieveResponse as DialogflowConnectionRetrieveResponse,
)
from .dynamic_emergency_address_create_params import (
    DynamicEmergencyAddressCreateParams as DynamicEmergencyAddressCreateParams,
)
from .inexplicit_number_order_create_response import (
    InexplicitNumberOrderCreateResponse as InexplicitNumberOrderCreateResponse,
)
from .messaging_hosted_number_delete_response import (
    MessagingHostedNumberDeleteResponse as MessagingHostedNumberDeleteResponse,
)
from .mobile_voice_connection_create_response import (
    MobileVoiceConnectionCreateResponse as MobileVoiceConnectionCreateResponse,
)
from .mobile_voice_connection_delete_response import (
    MobileVoiceConnectionDeleteResponse as MobileVoiceConnectionDeleteResponse,
)
from .mobile_voice_connection_update_response import (
    MobileVoiceConnectionUpdateResponse as MobileVoiceConnectionUpdateResponse,
)
from .number_order_phone_number_list_response import (
    NumberOrderPhoneNumberListResponse as NumberOrderPhoneNumberListResponse,
)
from .pagination_meta_cloudflare_ip_list_sync import (
    PaginationMetaCloudflareIPListSync as PaginationMetaCloudflareIPListSync,
)
from .public_internet_gateway_create_response import (
    PublicInternetGatewayCreateResponse as PublicInternetGatewayCreateResponse,
)
from .public_internet_gateway_delete_response import (
    PublicInternetGatewayDeleteResponse as PublicInternetGatewayDeleteResponse,
)
from .recording_transcription_delete_response import (
    RecordingTranscriptionDeleteResponse as RecordingTranscriptionDeleteResponse,
)
from .sim_card_order_preview_preview_response import (
    SimCardOrderPreviewPreviewResponse as SimCardOrderPreviewPreviewResponse,
)
from .sub_number_order_regulatory_requirement import (
    SubNumberOrderRegulatoryRequirement as SubNumberOrderRegulatoryRequirement,
)
from .virtual_cross_connect_retrieve_response import (
    VirtualCrossConnectRetrieveResponse as VirtualCrossConnectRetrieveResponse,
)
from .wireguard_peer_retrieve_config_response import (
    WireguardPeerRetrieveConfigResponse as WireguardPeerRetrieveConfigResponse,
)
from .available_phone_number_block_list_params import (
    AvailablePhoneNumberBlockListParams as AvailablePhoneNumberBlockListParams,
)
from .call_control_application_create_response import (
    CallControlApplicationCreateResponse as CallControlApplicationCreateResponse,
)
from .call_control_application_delete_response import (
    CallControlApplicationDeleteResponse as CallControlApplicationDeleteResponse,
)
from .call_control_application_update_response import (
    CallControlApplicationUpdateResponse as CallControlApplicationUpdateResponse,
)
from .conference_recording_saved_webhook_event import (
    ConferenceRecordingSavedWebhookEvent as ConferenceRecordingSavedWebhookEvent,
)
from .document_generate_download_link_response import (
    DocumentGenerateDownloadLinkResponse as DocumentGenerateDownloadLinkResponse,
)
from .dynamic_emergency_endpoint_create_params import (
    DynamicEmergencyEndpointCreateParams as DynamicEmergencyEndpointCreateParams,
)
from .global_ip_health_check_retrieve_response import (
    GlobalIPHealthCheckRetrieveResponse as GlobalIPHealthCheckRetrieveResponse,
)
from .notification_event_condition_list_params import (
    NotificationEventConditionListParams as NotificationEventConditionListParams,
)
from .outbound_voice_profile_retrieve_response import (
    OutboundVoiceProfileRetrieveResponse as OutboundVoiceProfileRetrieveResponse,
)
from .porting_order_phone_number_configuration import (
    PortingOrderPhoneNumberConfiguration as PortingOrderPhoneNumberConfiguration,
)
from .private_wireless_gateway_create_response import (
    PrivateWirelessGatewayCreateResponse as PrivateWirelessGatewayCreateResponse,
)
from .private_wireless_gateway_delete_response import (
    PrivateWirelessGatewayDeleteResponse as PrivateWirelessGatewayDeleteResponse,
)
from .regulatory_requirement_retrieve_response import (
    RegulatoryRequirementRetrieveResponse as RegulatoryRequirementRetrieveResponse,
)
from .sub_number_orders_report_create_response import (
    SubNumberOrdersReportCreateResponse as SubNumberOrdersReportCreateResponse,
)
from .verify_profile_message_template_response import (
    VerifyProfileMessageTemplateResponse as VerifyProfileMessageTemplateResponse,
)
from .authentication_provider_retrieve_response import (
    AuthenticationProviderRetrieveResponse as AuthenticationProviderRetrieveResponse,
)
from .call_machine_greeting_ended_webhook_event import (
    CallMachineGreetingEndedWebhookEvent as CallMachineGreetingEndedWebhookEvent,
)
from .conference_participant_left_webhook_event import (
    ConferenceParticipantLeftWebhookEvent as ConferenceParticipantLeftWebhookEvent,
)
from .conference_playback_started_webhook_event import (
    ConferencePlaybackStartedWebhookEvent as ConferencePlaybackStartedWebhookEvent,
)
from .custom_storage_credential_create_response import (
    CustomStorageCredentialCreateResponse as CustomStorageCredentialCreateResponse,
)
from .custom_storage_credential_update_response import (
    CustomStorageCredentialUpdateResponse as CustomStorageCredentialUpdateResponse,
)
from .customer_service_record_retrieve_response import (
    CustomerServiceRecordRetrieveResponse as CustomerServiceRecordRetrieveResponse,
)
from .dynamic_emergency_address_create_response import (
    DynamicEmergencyAddressCreateResponse as DynamicEmergencyAddressCreateResponse,
)
from .dynamic_emergency_address_delete_response import (
    DynamicEmergencyAddressDeleteResponse as DynamicEmergencyAddressDeleteResponse,
)
from .global_ip_health_check_type_list_response import (
    GlobalIPHealthCheckTypeListResponse as GlobalIPHealthCheckTypeListResponse,
)
from .inexplicit_number_order_retrieve_response import (
    InexplicitNumberOrderRetrieveResponse as InexplicitNumberOrderRetrieveResponse,
)
from .ledger_billing_group_report_create_params import (
    LedgerBillingGroupReportCreateParams as LedgerBillingGroupReportCreateParams,
)
from .messaging_hosted_number_order_list_params import (
    MessagingHostedNumberOrderListParams as MessagingHostedNumberOrderListParams,
)
from .messaging_profile_list_short_codes_params import (
    MessagingProfileListShortCodesParams as MessagingProfileListShortCodesParams,
)
from .mobile_voice_connection_retrieve_response import (
    MobileVoiceConnectionRetrieveResponse as MobileVoiceConnectionRetrieveResponse,
)
from .public_internet_gateway_retrieve_response import (
    PublicInternetGatewayRetrieveResponse as PublicInternetGatewayRetrieveResponse,
)
from .recording_transcription_retrieve_response import (
    RecordingTranscriptionRetrieveResponse as RecordingTranscriptionRetrieveResponse,
)
from .available_phone_number_block_list_response import (
    AvailablePhoneNumberBlockListResponse as AvailablePhoneNumberBlockListResponse,
)
from .call_control_application_retrieve_response import (
    CallControlApplicationRetrieveResponse as CallControlApplicationRetrieveResponse,
)
from .call_machine_detection_ended_webhook_event import (
    CallMachineDetectionEndedWebhookEvent as CallMachineDetectionEndedWebhookEvent,
)
from .country_coverage_retrieve_country_response import (
    CountryCoverageRetrieveCountryResponse as CountryCoverageRetrieveCountryResponse,
)
from .dynamic_emergency_endpoint_create_response import (
    DynamicEmergencyEndpointCreateResponse as DynamicEmergencyEndpointCreateResponse,
)
from .dynamic_emergency_endpoint_delete_response import (
    DynamicEmergencyEndpointDeleteResponse as DynamicEmergencyEndpointDeleteResponse,
)
from .external_connection_update_location_params import (
    ExternalConnectionUpdateLocationParams as ExternalConnectionUpdateLocationParams,
)
from .notification_event_condition_list_response import (
    NotificationEventConditionListResponse as NotificationEventConditionListResponse,
)
from .porting_order_retrieve_loa_template_params import (
    PortingOrderRetrieveLoaTemplateParams as PortingOrderRetrieveLoaTemplateParams,
)
from .porting_order_retrieve_requirements_params import (
    PortingOrderRetrieveRequirementsParams as PortingOrderRetrieveRequirementsParams,
)
from .private_wireless_gateway_retrieve_response import (
    PrivateWirelessGatewayRetrieveResponse as PrivateWirelessGatewayRetrieveResponse,
)
from .sub_number_orders_report_download_response import (
    SubNumberOrdersReportDownloadResponse as SubNumberOrdersReportDownloadResponse,
)
from .sub_number_orders_report_retrieve_response import (
    SubNumberOrdersReportRetrieveResponse as SubNumberOrdersReportRetrieveResponse,
)
from .telephony_credential_create_token_response import (
    TelephonyCredentialCreateTokenResponse as TelephonyCredentialCreateTokenResponse,
)
from .verify_profile_retrieve_templates_response import (
    VerifyProfileRetrieveTemplatesResponse as VerifyProfileRetrieveTemplatesResponse,
)
from .conference_participant_joined_webhook_event import (
    ConferenceParticipantJoinedWebhookEvent as ConferenceParticipantJoinedWebhookEvent,
)
from .custom_storage_credential_retrieve_response import (
    CustomStorageCredentialRetrieveResponse as CustomStorageCredentialRetrieveResponse,
)
from .dynamic_emergency_address_retrieve_response import (
    DynamicEmergencyAddressRetrieveResponse as DynamicEmergencyAddressRetrieveResponse,
)
from .external_voice_integrations_pagination_meta import (
    ExternalVoiceIntegrationsPaginationMeta as ExternalVoiceIntegrationsPaginationMeta,
)
from .global_ip_assignment_health_retrieve_params import (
    GlobalIPAssignmentHealthRetrieveParams as GlobalIPAssignmentHealthRetrieveParams,
)
from .global_ip_assignments_usage_retrieve_params import (
    GlobalIPAssignmentsUsageRetrieveParams as GlobalIPAssignmentsUsageRetrieveParams,
)
from .ledger_billing_group_report_create_response import (
    LedgerBillingGroupReportCreateResponse as LedgerBillingGroupReportCreateResponse,
)
from .messaging_hosted_number_order_create_params import (
    MessagingHostedNumberOrderCreateParams as MessagingHostedNumberOrderCreateParams,
)
from .messaging_numbers_bulk_update_create_params import (
    MessagingNumbersBulkUpdateCreateParams as MessagingNumbersBulkUpdateCreateParams,
)
from .messaging_profile_list_phone_numbers_params import (
    MessagingProfileListPhoneNumbersParams as MessagingProfileListPhoneNumbersParams,
)
from .number_order_phone_number_retrieve_response import (
    NumberOrderPhoneNumberRetrieveResponse as NumberOrderPhoneNumberRetrieveResponse,
)
from .porting_order_retrieve_sub_request_response import (
    PortingOrderRetrieveSubRequestResponse as PortingOrderRetrieveSubRequestResponse,
)
from .seti_retrieve_black_box_test_results_params import (
    SetiRetrieveBlackBoxTestResultsParams as SetiRetrieveBlackBoxTestResultsParams,
)
from .virtual_cross_connects_coverage_list_params import (
    VirtualCrossConnectsCoverageListParams as VirtualCrossConnectsCoverageListParams,
)
from .call_ai_gather_partial_results_webhook_event import (
    CallAIGatherPartialResultsWebhookEvent as CallAIGatherPartialResultsWebhookEvent,
)
from .dynamic_emergency_endpoint_retrieve_response import (
    DynamicEmergencyEndpointRetrieveResponse as DynamicEmergencyEndpointRetrieveResponse,
)
from .external_connection_update_location_response import (
    ExternalConnectionUpdateLocationResponse as ExternalConnectionUpdateLocationResponse,
)
from .porting_order_retrieve_requirements_response import (
    PortingOrderRetrieveRequirementsResponse as PortingOrderRetrieveRequirementsResponse,
)
from .sim_card_data_usage_notification_list_params import (
    SimCardDataUsageNotificationListParams as SimCardDataUsageNotificationListParams,
)
from .global_ip_assignment_health_retrieve_response import (
    GlobalIPAssignmentHealthRetrieveResponse as GlobalIPAssignmentHealthRetrieveResponse,
)
from .global_ip_assignments_usage_retrieve_response import (
    GlobalIPAssignmentsUsageRetrieveResponse as GlobalIPAssignmentsUsageRetrieveResponse,
)
from .ledger_billing_group_report_retrieve_response import (
    LedgerBillingGroupReportRetrieveResponse as LedgerBillingGroupReportRetrieveResponse,
)
from .messaging_hosted_number_order_create_response import (
    MessagingHostedNumberOrderCreateResponse as MessagingHostedNumberOrderCreateResponse,
)
from .messaging_hosted_number_order_delete_response import (
    MessagingHostedNumberOrderDeleteResponse as MessagingHostedNumberOrderDeleteResponse,
)
from .messaging_numbers_bulk_update_create_response import (
    MessagingNumbersBulkUpdateCreateResponse as MessagingNumbersBulkUpdateCreateResponse,
)
from .seti_retrieve_black_box_test_results_response import (
    SetiRetrieveBlackBoxTestResultsResponse as SetiRetrieveBlackBoxTestResultsResponse,
)
from .virtual_cross_connects_coverage_list_response import (
    VirtualCrossConnectsCoverageListResponse as VirtualCrossConnectsCoverageListResponse,
)
from .advanced_order_update_requirement_group_params import (
    AdvancedOrderUpdateRequirementGroupParams as AdvancedOrderUpdateRequirementGroupParams,
)
from .porting_order_phone_number_configuration_param import (
    PortingOrderPhoneNumberConfigurationParam as PortingOrderPhoneNumberConfigurationParam,
)
from .sim_card_data_usage_notification_create_params import (
    SimCardDataUsageNotificationCreateParams as SimCardDataUsageNotificationCreateParams,
)
from .sim_card_data_usage_notification_update_params import (
    SimCardDataUsageNotificationUpdateParams as SimCardDataUsageNotificationUpdateParams,
)
from .messaging_hosted_number_order_retrieve_response import (
    MessagingHostedNumberOrderRetrieveResponse as MessagingHostedNumberOrderRetrieveResponse,
)
from .messaging_numbers_bulk_update_retrieve_response import (
    MessagingNumbersBulkUpdateRetrieveResponse as MessagingNumbersBulkUpdateRetrieveResponse,
)
from .porting_order_retrieve_exception_types_response import (
    PortingOrderRetrieveExceptionTypesResponse as PortingOrderRetrieveExceptionTypesResponse,
)
from .sim_card_list_wireless_connectivity_logs_params import (
    SimCardListWirelessConnectivityLogsParams as SimCardListWirelessConnectivityLogsParams,
)
from .storage_list_migration_source_coverage_response import (
    StorageListMigrationSourceCoverageResponse as StorageListMigrationSourceCoverageResponse,
)
from .advanced_order_update_requirement_group_response import (
    AdvancedOrderUpdateRequirementGroupResponse as AdvancedOrderUpdateRequirementGroupResponse,
)
from .call_recording_transcription_saved_webhook_event import (
    CallRecordingTranscriptionSavedWebhookEvent as CallRecordingTranscriptionSavedWebhookEvent,
)
from .conference_participant_speak_ended_webhook_event import (
    ConferenceParticipantSpeakEndedWebhookEvent as ConferenceParticipantSpeakEndedWebhookEvent,
)
from .sim_card_data_usage_notification_create_response import (
    SimCardDataUsageNotificationCreateResponse as SimCardDataUsageNotificationCreateResponse,
)
from .sim_card_data_usage_notification_delete_response import (
    SimCardDataUsageNotificationDeleteResponse as SimCardDataUsageNotificationDeleteResponse,
)
from .sim_card_data_usage_notification_update_response import (
    SimCardDataUsageNotificationUpdateResponse as SimCardDataUsageNotificationUpdateResponse,
)
from .sub_number_order_update_requirement_group_params import (
    SubNumberOrderUpdateRequirementGroupParams as SubNumberOrderUpdateRequirementGroupParams,
)
from .call_machine_premium_greeting_ended_webhook_event import (
    CallMachinePremiumGreetingEndedWebhookEvent as CallMachinePremiumGreetingEndedWebhookEvent,
)
from .sim_card_list_wireless_connectivity_logs_response import (
    SimCardListWirelessConnectivityLogsResponse as SimCardListWirelessConnectivityLogsResponse,
)
from .call_conversation_insights_generated_webhook_event import (
    CallConversationInsightsGeneratedWebhookEvent as CallConversationInsightsGeneratedWebhookEvent,
)
from .call_machine_premium_detection_ended_webhook_event import (
    CallMachinePremiumDetectionEndedWebhookEvent as CallMachinePremiumDetectionEndedWebhookEvent,
)
from .conference_participant_speak_started_webhook_event import (
    ConferenceParticipantSpeakStartedWebhookEvent as ConferenceParticipantSpeakStartedWebhookEvent,
)
from .managed_account_update_global_channel_limit_params import (
    ManagedAccountUpdateGlobalChannelLimitParams as ManagedAccountUpdateGlobalChannelLimitParams,
)
from .sim_card_data_usage_notification_retrieve_response import (
    SimCardDataUsageNotificationRetrieveResponse as SimCardDataUsageNotificationRetrieveResponse,
)
from .sub_number_order_update_requirement_group_response import (
    SubNumberOrderUpdateRequirementGroupResponse as SubNumberOrderUpdateRequirementGroupResponse,
)
from .conference_participant_playback_ended_webhook_event import (
    ConferenceParticipantPlaybackEndedWebhookEvent as ConferenceParticipantPlaybackEndedWebhookEvent,
)
from .messaging_hosted_number_order_validate_codes_params import (
    MessagingHostedNumberOrderValidateCodesParams as MessagingHostedNumberOrderValidateCodesParams,
)
from .porting_order_retrieve_allowed_foc_windows_response import (
    PortingOrderRetrieveAllowedFocWindowsResponse as PortingOrderRetrieveAllowedFocWindowsResponse,
)
from .call_ai_gather_message_history_updated_webhook_event import (
    CallAIGatherMessageHistoryUpdatedWebhookEvent as CallAIGatherMessageHistoryUpdatedWebhookEvent,
)
from .managed_account_update_global_channel_limit_response import (
    ManagedAccountUpdateGlobalChannelLimitResponse as ManagedAccountUpdateGlobalChannelLimitResponse,
)
from .number_order_phone_number_update_requirements_params import (
    NumberOrderPhoneNumberUpdateRequirementsParams as NumberOrderPhoneNumberUpdateRequirementsParams,
)
from .phone_numbers_regulatory_requirement_retrieve_params import (
    PhoneNumbersRegulatoryRequirementRetrieveParams as PhoneNumbersRegulatoryRequirementRetrieveParams,
)
from .conference_participant_playback_started_webhook_event import (
    ConferenceParticipantPlaybackStartedWebhookEvent as ConferenceParticipantPlaybackStartedWebhookEvent,
)
from .messaging_hosted_number_order_validate_codes_response import (
    MessagingHostedNumberOrderValidateCodesResponse as MessagingHostedNumberOrderValidateCodesResponse,
)
from .messaging_hosted_number_order_check_eligibility_params import (
    MessagingHostedNumberOrderCheckEligibilityParams as MessagingHostedNumberOrderCheckEligibilityParams,
)
from .number_order_phone_number_update_requirements_response import (
    NumberOrderPhoneNumberUpdateRequirementsResponse as NumberOrderPhoneNumberUpdateRequirementsResponse,
)
from .phone_numbers_regulatory_requirement_retrieve_response import (
    PhoneNumbersRegulatoryRequirementRetrieveResponse as PhoneNumbersRegulatoryRequirementRetrieveResponse,
)
from .messaging_hosted_number_order_check_eligibility_response import (
    MessagingHostedNumberOrderCheckEligibilityResponse as MessagingHostedNumberOrderCheckEligibilityResponse,
)
from .well_known_retrieve_protected_resource_metadata_response import (
    WellKnownRetrieveProtectedResourceMetadataResponse as WellKnownRetrieveProtectedResourceMetadataResponse,
)
from .number_order_phone_number_update_requirement_group_params import (
    NumberOrderPhoneNumberUpdateRequirementGroupParams as NumberOrderPhoneNumberUpdateRequirementGroupParams,
)
from .well_known_retrieve_authorization_server_metadata_response import (
    WellKnownRetrieveAuthorizationServerMetadataResponse as WellKnownRetrieveAuthorizationServerMetadataResponse,
)
from .customer_service_record_verify_phone_number_coverage_params import (
    CustomerServiceRecordVerifyPhoneNumberCoverageParams as CustomerServiceRecordVerifyPhoneNumberCoverageParams,
)
from .number_order_phone_number_update_requirement_group_response import (
    NumberOrderPhoneNumberUpdateRequirementGroupResponse as NumberOrderPhoneNumberUpdateRequirementGroupResponse,
)
from .customer_service_record_verify_phone_number_coverage_response import (
    CustomerServiceRecordVerifyPhoneNumberCoverageResponse as CustomerServiceRecordVerifyPhoneNumberCoverageResponse,
)
from .messaging_hosted_number_order_create_verification_codes_params import (
    MessagingHostedNumberOrderCreateVerificationCodesParams as MessagingHostedNumberOrderCreateVerificationCodesParams,
)
from .messaging_hosted_number_order_create_verification_codes_response import (
    MessagingHostedNumberOrderCreateVerificationCodesResponse as MessagingHostedNumberOrderCreateVerificationCodesResponse,
)
from .managed_account_get_allocatable_global_outbound_channels_response import (
    ManagedAccountGetAllocatableGlobalOutboundChannelsResponse as ManagedAccountGetAllocatableGlobalOutboundChannelsResponse,
)

# Rebuild cyclical models only after all modules are imported.
# This ensures that, when building the deferred (due to cyclical references) model schema,
# Pydantic can resolve the necessary references.
# See: https://github.com/pydantic/pydantic/issues/11250 for more context.
if _compat.PYDANTIC_V1:
    ai.recursive_cluster.RecursiveCluster.update_forward_refs()  # type: ignore
    ai.cluster_retrieve_response.ClusterRetrieveResponse.update_forward_refs()  # type: ignore
else:
    ai.recursive_cluster.RecursiveCluster.model_rebuild(_parent_namespace_depth=0)
    ai.cluster_retrieve_response.ClusterRetrieveResponse.model_rebuild(_parent_namespace_depth=0)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel
from .porting_order import PortingOrder

__all__ = ["PortingOrderCreateResponse"]


class PortingOrderCreateResponse(BaseModel):
    data: Optional[List[PortingOrder]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["ManagedAccountCreateParams"]


class ManagedAccountCreateParams(TypedDict, total=False):
    business_name: Required[str]
    """
    The name of the business for which the new managed account is being created,
    that will be used as the managed accounts's organization's name.
    """

    email: str
    """The email address for the managed account.

    If not provided, the email address will be generated based on the email address
    of the manager account.
    """

    managed_account_allow_custom_pricing: bool
    """
    Boolean value that indicates if the managed account is able to have custom
    pricing set for it or not. If false, uses the pricing of the manager account.
    Defaults to false. This value may be changed after creation, but there may be
    time lag between when the value is changed and pricing changes take effect.
    """

    password: str
    """Password for the managed account.

    If a password is not supplied, the account will not be able to be signed into
    directly. (A password reset may still be performed later to enable sign-in via
    password.)
    """

    rollup_billing: bool
    """
    Boolean value that indicates if the billing information and charges to the
    managed account "roll up" to the manager account. If true, the managed account
    will not have its own balance and will use the shared balance with the manager
    account. This value cannot be changed after account creation without going
    through Telnyx support as changes require manual updates to the account ledger.
    Defaults to false.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypedDict

from ..._types import SequenceNotStr
from ..calls.loopcount_param import LoopcountParam

__all__ = ["ActionPlayParams"]


class ActionPlayParams(TypedDict, total=False):
    audio_url: str
    """The URL of a file to be played back in the conference.

    media_name and audio_url cannot be used together in one request.
    """

    call_control_ids: SequenceNotStr[str]
    """
    List of call control ids identifying participants the audio file should be
    played to. If not given, the audio file will be played to the entire conference.
    """

    loop: LoopcountParam
    """The number of times the audio file should be played.

    If supplied, the value must be an integer between 1 and 100, or the special
    string `infinity` for an endless loop.
    """

    media_name: str
    """The media_name of a file to be played back in the conference.

    The media_name must point to a file previously uploaded to
    api.telnyx.com/v2/media by the same user/organization. The file must either be a
    WAV or MP3 file.
    """

    region: Literal["Australia", "Europe", "Middle East", "US"]
    """Region where the conference data is located.

    Defaults to the region defined in user's data locality settings (Europe or US).
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...types import wireless_retrieve_regions_params
from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from .detail_records_reports import (
    DetailRecordsReportsResource,
    AsyncDetailRecordsReportsResource,
    DetailRecordsReportsResourceWithRawResponse,
    AsyncDetailRecordsReportsResourceWithRawResponse,
    DetailRecordsReportsResourceWithStreamingResponse,
    AsyncDetailRecordsReportsResourceWithStreamingResponse,
)
from ...types.wireless_retrieve_regions_response import WirelessRetrieveRegionsResponse

__all__ = ["WirelessResource", "AsyncWirelessResource"]


class WirelessResource(SyncAPIResource):
    @cached_property
    def detail_records_reports(self) -> DetailRecordsReportsResource:
        return DetailRecordsReportsResource(self._client)

    @cached_property
    def with_raw_response(self) -> WirelessResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return WirelessResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> WirelessResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return WirelessResourceWithStreamingResponse(self)

    def retrieve_regions(
        self,
        *,
        product: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> WirelessRetrieveRegionsResponse:
        """
        Retrieve all wireless regions for the given product.

        Args:
          product: The product for which to list regions (e.g., 'public_ips',
              'private_wireless_gateways').

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/wireless/regions",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"product": product}, wireless_retrieve_regions_params.WirelessRetrieveRegionsParams
                ),
            ),
            cast_to=WirelessRetrieveRegionsResponse,
        )


class AsyncWirelessResource(AsyncAPIResource):
    @cached_property
    def detail_records_reports(self) -> AsyncDetailRecordsReportsResource:
        return AsyncDetailRecordsReportsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncWirelessResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncWirelessResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncWirelessResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncWirelessResourceWithStreamingResponse(self)

    async def retrieve_regions(
        self,
        *,
        product: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> WirelessRetrieveRegionsResponse:
        """
        Retrieve all wireless regions for the given product.

        Args:
          product: The product for which to list regions (e.g., 'public_ips',
              'private_wireless_gateways').

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/wireless/regions",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"product": product}, wireless_retrieve_regions_params.WirelessRetrieveRegionsParams
                ),
            ),
            cast_to=WirelessRetrieveRegionsResponse,
        )


class WirelessResourceWithRawResponse:
    def __init__(self, wireless: WirelessResource) -> None:
        self._wireless = wireless

        self.retrieve_regions = to_raw_response_wrapper(
            wireless.retrieve_regions,
        )

    @cached_property
    def detail_records_reports(self) -> DetailRecordsReportsResourceWithRawResponse:
        return DetailRecordsReportsResourceWithRawResponse(self._wireless.detail_records_reports)


class AsyncWirelessResourceWithRawResponse:
    def __init__(self, wireless: AsyncWirelessResource) -> None:
        self._wireless = wireless

        self.retrieve_regions = async_to_raw_response_wrapper(
            wireless.retrieve_regions,
        )

    @cached_property
    def detail_records_reports(self) -> AsyncDetailRecordsReportsResourceWithRawResponse:
        return AsyncDetailRecordsReportsResourceWithRawResponse(self._wireless.detail_records_reports)


class WirelessResourceWithStreamingResponse:
    def __init__(self, wireless: WirelessResource) -> None:
        self._wireless = wireless

        self.retrieve_regions = to_streamed_response_wrapper(
            wireless.retrieve_regions,
        )

    @cached_property
    def detail_records_reports(self) -> DetailRecordsReportsResourceWithStreamingResponse:
        return DetailRecordsReportsResourceWithStreamingResponse(self._wireless.detail_records_reports)


class AsyncWirelessResourceWithStreamingResponse:
    def __init__(self, wireless: AsyncWirelessResource) -> None:
        self._wireless = wireless

        self.retrieve_regions = async_to_streamed_response_wrapper(
            wireless.retrieve_regions,
        )

    @cached_property
    def detail_records_reports(self) -> AsyncDetailRecordsReportsResourceWithStreamingResponse:
        return AsyncDetailRecordsReportsResourceWithStreamingResponse(self._wireless.detail_records_reports)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types.ai import (
    MissionData,
    MissionCreateResponse,
    MissionRetrieveResponse,
    MissionListEventsResponse,
    MissionUpdateMissionResponse,
)
from telnyx.pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMissions:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create(self, client: Telnyx) -> None:
        mission = client.ai.missions.create(
            name="name",
        )
        assert_matches_type(MissionCreateResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_create_with_all_params(self, client: Telnyx) -> None:
        mission = client.ai.missions.create(
            name="name",
            description="description",
            execution_mode="external",
            instructions="instructions",
            metadata={"foo": "bar"},
            model="model",
        )
        assert_matches_type(MissionCreateResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_create(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.create(
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert_matches_type(MissionCreateResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_create(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.create(
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert_matches_type(MissionCreateResponse, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: Telnyx) -> None:
        mission = client.ai.missions.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(MissionRetrieveResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert_matches_type(MissionRetrieveResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert_matches_type(MissionRetrieveResponse, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list(self, client: Telnyx) -> None:
        mission = client.ai.missions.list()
        assert_matches_type(SyncDefaultFlatPagination[MissionData], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_with_all_params(self, client: Telnyx) -> None:
        mission = client.ai.missions.list(
            page_number=1,
            page_size=1,
        )
        assert_matches_type(SyncDefaultFlatPagination[MissionData], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert_matches_type(SyncDefaultFlatPagination[MissionData], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert_matches_type(SyncDefaultFlatPagination[MissionData], mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_clone_mission(self, client: Telnyx) -> None:
        mission = client.ai.missions.clone_mission(
            "mission_id",
        )
        assert_matches_type(object, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_clone_mission(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.clone_mission(
            "mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert_matches_type(object, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_clone_mission(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.clone_mission(
            "mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert_matches_type(object, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_clone_mission(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.with_raw_response.clone_mission(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_delete_mission(self, client: Telnyx) -> None:
        mission = client.ai.missions.delete_mission(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert mission is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_delete_mission(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.delete_mission(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert mission is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_delete_mission(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.delete_mission(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert mission is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_delete_mission(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.with_raw_response.delete_mission(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_events(self, client: Telnyx) -> None:
        mission = client.ai.missions.list_events()
        assert_matches_type(SyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_list_events_with_all_params(self, client: Telnyx) -> None:
        mission = client.ai.missions.list_events(
            page_number=1,
            page_size=1,
            type="type",
        )
        assert_matches_type(SyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_list_events(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.list_events()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert_matches_type(SyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_list_events(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.list_events() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert_matches_type(SyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_mission(self, client: Telnyx) -> None:
        mission = client.ai.missions.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_update_mission_with_all_params(self, client: Telnyx) -> None:
        mission = client.ai.missions.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            description="description",
            execution_mode="external",
            instructions="instructions",
            metadata={"foo": "bar"},
            model="model",
            name="name",
        )
        assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_update_mission(self, client: Telnyx) -> None:
        response = client.ai.missions.with_raw_response.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = response.parse()
        assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_update_mission(self, client: Telnyx) -> None:
        with client.ai.missions.with_streaming_response.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = response.parse()
            assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_update_mission(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.with_raw_response.update_mission(
                mission_id="",
            )


class TestAsyncMissions:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.create(
            name="name",
        )
        assert_matches_type(MissionCreateResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.create(
            name="name",
            description="description",
            execution_mode="external",
            instructions="instructions",
            metadata={"foo": "bar"},
            model="model",
        )
        assert_matches_type(MissionCreateResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.create(
            name="name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert_matches_type(MissionCreateResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.create(
            name="name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert_matches_type(MissionCreateResponse, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(MissionRetrieveResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert_matches_type(MissionRetrieveResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.retrieve(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert_matches_type(MissionRetrieveResponse, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.list()
        assert_matches_type(AsyncDefaultFlatPagination[MissionData], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.list(
            page_number=1,
            page_size=1,
        )
        assert_matches_type(AsyncDefaultFlatPagination[MissionData], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert_matches_type(AsyncDefaultFlatPagination[MissionData], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert_matches_type(AsyncDefaultFlatPagination[MissionData], mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_clone_mission(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.clone_mission(
            "mission_id",
        )
        assert_matches_type(object, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_clone_mission(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.clone_mission(
            "mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert_matches_type(object, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_clone_mission(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.clone_mission(
            "mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert_matches_type(object, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_clone_mission(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.with_raw_response.clone_mission(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_delete_mission(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.delete_mission(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert mission is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_delete_mission(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.delete_mission(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert mission is None

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_delete_mission(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.delete_mission(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert mission is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_delete_mission(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.with_raw_response.delete_mission(
                "",
            )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_events(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.list_events()
        assert_matches_type(AsyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_list_events_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.list_events(
            page_number=1,
            page_size=1,
            type="type",
        )
        assert_matches_type(AsyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_list_events(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.list_events()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert_matches_type(AsyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_list_events(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.list_events() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert_matches_type(AsyncDefaultFlatPagination[MissionListEventsResponse], mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_mission(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_update_mission_with_all_params(self, async_client: AsyncTelnyx) -> None:
        mission = await async_client.ai.missions.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            description="description",
            execution_mode="external",
            instructions="instructions",
            metadata={"foo": "bar"},
            model="model",
            name="name",
        )
        assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_update_mission(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.with_raw_response.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mission = await response.parse()
        assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_update_mission(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.with_streaming_response.update_mission(
            mission_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mission = await response.parse()
            assert_matches_type(MissionUpdateMissionResponse, mission, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_update_mission(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.with_raw_response.update_mission(
                mission_id="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import room_participant_list_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination
from .._base_client import AsyncPaginator, make_request_options
from ..types.shared.room_participant import RoomParticipant
from ..types.room_participant_retrieve_response import RoomParticipantRetrieveResponse

__all__ = ["RoomParticipantsResource", "AsyncRoomParticipantsResource"]


class RoomParticipantsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> RoomParticipantsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return RoomParticipantsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> RoomParticipantsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return RoomParticipantsResourceWithStreamingResponse(self)

    def retrieve(
        self,
        room_participant_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RoomParticipantRetrieveResponse:
        """
        View a room participant.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not room_participant_id:
            raise ValueError(
                f"Expected a non-empty value for `room_participant_id` but received {room_participant_id!r}"
            )
        return self._get(
            f"/room_participants/{room_participant_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RoomParticipantRetrieveResponse,
        )

    def list(
        self,
        *,
        filter: room_participant_list_params.Filter | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncDefaultFlatPagination[RoomParticipant]:
        """
        View a list of room participants.

        Args:
          filter:
              Consolidated filter parameter (deepObject style). Originally:
              filter[date_joined_at][eq], filter[date_joined_at][gte],
              filter[date_joined_at][lte], filter[date_updated_at][eq],
              filter[date_updated_at][gte], filter[date_updated_at][lte],
              filter[date_left_at][eq], filter[date_left_at][gte], filter[date_left_at][lte],
              filter[context], filter[session_id]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/room_participants",
            page=SyncDefaultFlatPagination[RoomParticipant],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    room_participant_list_params.RoomParticipantListParams,
                ),
            ),
            model=RoomParticipant,
        )


class AsyncRoomParticipantsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncRoomParticipantsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncRoomParticipantsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncRoomParticipantsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncRoomParticipantsResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        room_participant_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> RoomParticipantRetrieveResponse:
        """
        View a room participant.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not room_participant_id:
            raise ValueError(
                f"Expected a non-empty value for `room_participant_id` but received {room_participant_id!r}"
            )
        return await self._get(
            f"/room_participants/{room_participant_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=RoomParticipantRetrieveResponse,
        )

    def list(
        self,
        *,
        filter: room_participant_list_params.Filter | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[RoomParticipant, AsyncDefaultFlatPagination[RoomParticipant]]:
        """
        View a list of room participants.

        Args:
          filter:
              Consolidated filter parameter (deepObject style). Originally:
              filter[date_joined_at][eq], filter[date_joined_at][gte],
              filter[date_joined_at][lte], filter[date_updated_at][eq],
              filter[date_updated_at][gte], filter[date_updated_at][lte],
              filter[date_left_at][eq], filter[date_left_at][gte], filter[date_left_at][lte],
              filter[context], filter[session_id]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/room_participants",
            page=AsyncDefaultFlatPagination[RoomParticipant],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    room_participant_list_params.RoomParticipantListParams,
                ),
            ),
            model=RoomParticipant,
        )


class RoomParticipantsResourceWithRawResponse:
    def __init__(self, room_participants: RoomParticipantsResource) -> None:
        self._room_participants = room_participants

        self.retrieve = to_raw_response_wrapper(
            room_participants.retrieve,
        )
        self.list = to_raw_response_wrapper(
            room_participants.list,
        )


class AsyncRoomParticipantsResourceWithRawResponse:
    def __init__(self, room_participants: AsyncRoomParticipantsResource) -> None:
        self._room_participants = room_participants

        self.retrieve = async_to_raw_response_wrapper(
            room_participants.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            room_participants.list,
        )


class RoomParticipantsResourceWithStreamingResponse:
    def __init__(self, room_participants: RoomParticipantsResource) -> None:
        self._room_participants = room_participants

        self.retrieve = to_streamed_response_wrapper(
            room_participants.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            room_participants.list,
        )


class AsyncRoomParticipantsResourceWithStreamingResponse:
    def __init__(self, room_participants: AsyncRoomParticipantsResource) -> None:
        self._room_participants = room_participants

        self.retrieve = async_to_streamed_response_wrapper(
            room_participants.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            room_participants.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["WirelessBlocklistListParams"]


class WirelessBlocklistListParams(TypedDict, total=False):
    filter_name: Annotated[str, PropertyInfo(alias="filter[name]")]
    """The name of the Wireless Blocklist."""

    filter_type: Annotated[str, PropertyInfo(alias="filter[type]")]
    """When the Private Wireless Gateway was last updated."""

    filter_values: Annotated[str, PropertyInfo(alias="filter[values]")]
    """Values to filter on (inclusive)."""

    page_number: Annotated[int, PropertyInfo(alias="page[number]")]
    """The page number to load."""

    page_size: Annotated[int, PropertyInfo(alias="page[size]")]
    """The size of the page."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["WirelessRetrieveRegionsParams"]


class WirelessRetrieveRegionsParams(TypedDict, total=False):
    product: Required[str]
    """
    The product for which to list regions (e.g., 'public_ips',
    'private_wireless_gateways').
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["PrivateWirelessGatewayListParams"]


class PrivateWirelessGatewayListParams(TypedDict, total=False):
    filter_created_at: Annotated[str, PropertyInfo(alias="filter[created_at]")]
    """Private Wireless Gateway resource creation date."""

    filter_ip_range: Annotated[str, PropertyInfo(alias="filter[ip_range]")]
    """The IP address range of the Private Wireless Gateway."""

    filter_name: Annotated[str, PropertyInfo(alias="filter[name]")]
    """The name of the Private Wireless Gateway."""

    filter_region_code: Annotated[str, PropertyInfo(alias="filter[region_code]")]
    """The name of the region where the Private Wireless Gateway is deployed."""

    filter_updated_at: Annotated[str, PropertyInfo(alias="filter[updated_at]")]
    """When the Private Wireless Gateway was last updated."""

    page_number: Annotated[int, PropertyInfo(alias="page[number]")]
    """The page number to load."""

    page_size: Annotated[int, PropertyInfo(alias="page[size]")]
    """The size of the page."""
